# coding: utf-8

# flake8: noqa
"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


# import models into model package
from marqeta_client.models.ach_list_response import ACHListResponse
from marqeta_client.models.ach_return import ACHReturn
from marqeta_client.models.ach_reversal_request import ACHReversalRequest
from marqeta_client.models.atc_information_model import ATCInformationModel
from marqeta_client.models.accepted_countries_list_response import AcceptedCountriesListResponse
from marqeta_client.models.accepted_countries_model import AcceptedCountriesModel
from marqeta_client.models.accepted_countries_update_model import AcceptedCountriesUpdateModel
from marqeta_client.models.access_token_response import AccessTokenResponse
from marqeta_client.models.account import Account
from marqeta_client.models.account_funding import AccountFunding
from marqeta_client.models.account_funding_receiver_data import AccountFundingReceiverData
from marqeta_client.models.account_funding_request import AccountFundingRequest
from marqeta_client.models.account_holder_group_config import AccountHolderGroupConfig
from marqeta_client.models.account_holder_group_list_response import AccountHolderGroupListResponse
from marqeta_client.models.account_holder_group_request import AccountHolderGroupRequest
from marqeta_client.models.account_holder_group_response import AccountHolderGroupResponse
from marqeta_client.models.account_holder_group_update_request import AccountHolderGroupUpdateRequest
from marqeta_client.models.account_model import AccountModel
from marqeta_client.models.ach_model import AchModel
from marqeta_client.models.ach_partner_request_model import AchPartnerRequestModel
from marqeta_client.models.ach_response_model import AchResponseModel
from marqeta_client.models.ach_verification_model import AchVerificationModel
from marqeta_client.models.acquirer import Acquirer
from marqeta_client.models.activation_actions import ActivationActions
from marqeta_client.models.address_request_model import AddressRequestModel
from marqeta_client.models.address_response_model import AddressResponseModel
from marqeta_client.models.address_verification import AddressVerification
from marqeta_client.models.address_verification_model import AddressVerificationModel
from marqeta_client.models.address_verification_source import AddressVerificationSource
from marqeta_client.models.adv_auth_request_model import AdvAuthRequestModel
from marqeta_client.models.advanced_auth_card_acceptor_model import AdvancedAuthCardAcceptorModel
from marqeta_client.models.advanced_auth_card_options import AdvancedAuthCardOptions
from marqeta_client.models.advanced_auth_other_poi import AdvancedAuthOtherPOI
from marqeta_client.models.advanced_auth_poi import AdvancedAuthPOI
from marqeta_client.models.advanced_clearing_request_model import AdvancedClearingRequestModel
from marqeta_client.models.advanced_simulation_response_model import AdvancedSimulationResponseModel
from marqeta_client.models.advice_request_model import AdviceRequestModel
from marqeta_client.models.airline import Airline
from marqeta_client.models.android_push_token_request_address import AndroidPushTokenRequestAddress
from marqeta_client.models.android_push_tokenize_request_data import AndroidPushTokenizeRequestData
from marqeta_client.models.application import Application
from marqeta_client.models.auth_control_exempt_mids_list_response import AuthControlExemptMidsListResponse
from marqeta_client.models.auth_control_exempt_mids_request import AuthControlExemptMidsRequest
from marqeta_client.models.auth_control_exempt_mids_response import AuthControlExemptMidsResponse
from marqeta_client.models.auth_control_exempt_mids_update_request import AuthControlExemptMidsUpdateRequest
from marqeta_client.models.auth_control_list_response import AuthControlListResponse
from marqeta_client.models.auth_control_merchant_scope import AuthControlMerchantScope
from marqeta_client.models.auth_control_request import AuthControlRequest
from marqeta_client.models.auth_control_response import AuthControlResponse
from marqeta_client.models.auth_control_update_request import AuthControlUpdateRequest
from marqeta_client.models.auth_controls import AuthControls
from marqeta_client.models.auth_request_model import AuthRequestModel
from marqeta_client.models.auth_user import AuthUser
from marqeta_client.models.auth_user_request import AuthUserRequest
from marqeta_client.models.auth_user_update_request import AuthUserUpdateRequest
from marqeta_client.models.authentication import Authentication
from marqeta_client.models.authorization_advice_model import AuthorizationAdviceModel
from marqeta_client.models.auto_commando_mode_program_funding_source_response import AutoCommandoModeProgramFundingSourceResponse
from marqeta_client.models.auto_commando_mode_request import AutoCommandoModeRequest
from marqeta_client.models.auto_commando_mode_response import AutoCommandoModeResponse
from marqeta_client.models.auto_reload_association import AutoReloadAssociation
from marqeta_client.models.auto_reload_list_response import AutoReloadListResponse
from marqeta_client.models.auto_reload_model import AutoReloadModel
from marqeta_client.models.auto_reload_response_model import AutoReloadResponseModel
from marqeta_client.models.auto_reload_update_model import AutoReloadUpdateModel
from marqeta_client.models.available import Available
from marqeta_client.models.avs_control_options import AvsControlOptions
from marqeta_client.models.avs_controls import AvsControls
from marqeta_client.models.avs_information import AvsInformation
from marqeta_client.models.balance_cache_model import BalanceCacheModel
from marqeta_client.models.balance_inquiry_request_model import BalanceInquiryRequestModel
from marqeta_client.models.bank_account_funding_source_model import BankAccountFundingSourceModel
from marqeta_client.models.bank_account_funding_source_model_all_of import BankAccountFundingSourceModelAllOf
from marqeta_client.models.bank_transfer_clearing_request_model import BankTransferClearingRequestModel
from marqeta_client.models.bank_transfer_list_response import BankTransferListResponse
from marqeta_client.models.bank_transfer_request_model import BankTransferRequestModel
from marqeta_client.models.bank_transfer_response_model import BankTransferResponseModel
from marqeta_client.models.bank_transfer_transition_list_response import BankTransferTransitionListResponse
from marqeta_client.models.bank_transfer_transition_request_model import BankTransferTransitionRequestModel
from marqeta_client.models.bank_transfer_transition_response_model import BankTransferTransitionResponseModel
from marqeta_client.models.base_ach_extended_response_model import BaseAchExtendedResponseModel
from marqeta_client.models.base_ach_request_model import BaseAchRequestModel
from marqeta_client.models.base_ach_response_model import BaseAchResponseModel
from marqeta_client.models.beneficial_owner_request import BeneficialOwnerRequest
from marqeta_client.models.beneficial_owner_response import BeneficialOwnerResponse
from marqeta_client.models.bill_payment_completion_request import BillPaymentCompletionRequest
from marqeta_client.models.bill_payment_transaction_request import BillPaymentTransactionRequest
from marqeta_client.models.billing_address import BillingAddress
from marqeta_client.models.bin_pan_issued_count_response import BinPanIssuedCountResponse
from marqeta_client.models.bulk_card_order_list_response import BulkCardOrderListResponse
from marqeta_client.models.bulk_issuance_request import BulkIssuanceRequest
from marqeta_client.models.bulk_issuance_response import BulkIssuanceResponse
from marqeta_client.models.bulk_request_model import BulkRequestModel
from marqeta_client.models.business_card_holder_list_response import BusinessCardHolderListResponse
from marqeta_client.models.business_card_holder_response import BusinessCardHolderResponse
from marqeta_client.models.business_card_holder_update import BusinessCardHolderUpdate
from marqeta_client.models.business_cardholder import BusinessCardholder
from marqeta_client.models.business_incorporation import BusinessIncorporation
from marqeta_client.models.business_incorporation_response import BusinessIncorporationResponse
from marqeta_client.models.business_metadata import BusinessMetadata
from marqeta_client.models.business_proprietor import BusinessProprietor
from marqeta_client.models.business_proprietor_response import BusinessProprietorResponse
from marqeta_client.models.business_transition_list_response import BusinessTransitionListResponse
from marqeta_client.models.business_transition_request import BusinessTransitionRequest
from marqeta_client.models.business_transition_response import BusinessTransitionResponse
from marqeta_client.models.business_user_card_holder_list_response import BusinessUserCardHolderListResponse
from marqeta_client.models.cache_error import CacheError
from marqeta_client.models.cacheable import Cacheable
from marqeta_client.models.calculation_schedule import CalculationSchedule
from marqeta_client.models.calculation_schedule_list_response import CalculationScheduleListResponse
from marqeta_client.models.card_acceptor_model import CardAcceptorModel
from marqeta_client.models.card_fulfillment_request import CardFulfillmentRequest
from marqeta_client.models.card_fulfillment_response import CardFulfillmentResponse
from marqeta_client.models.card_holder_address_model import CardHolderAddressModel
from marqeta_client.models.card_holder_address_update_model import CardHolderAddressUpdateModel
from marqeta_client.models.card_holder_model import CardHolderModel
from marqeta_client.models.card_holder_note_list_response import CardHolderNoteListResponse
from marqeta_client.models.card_inventory_request import CardInventoryRequest
from marqeta_client.models.card_inventory_response import CardInventoryResponse
from marqeta_client.models.card_life_cycle import CardLifeCycle
from marqeta_client.models.card_list_response import CardListResponse
from marqeta_client.models.card_metadata import CardMetadata
from marqeta_client.models.card_options import CardOptions
from marqeta_client.models.card_personalization import CardPersonalization
from marqeta_client.models.card_product_config import CardProductConfig
from marqeta_client.models.card_product_fulfillment import CardProductFulfillment
from marqeta_client.models.card_product_fulfillment_response import CardProductFulfillmentResponse
from marqeta_client.models.card_product_list_response import CardProductListResponse
from marqeta_client.models.card_product_request import CardProductRequest
from marqeta_client.models.card_product_response import CardProductResponse
from marqeta_client.models.card_product_update_model import CardProductUpdateModel
from marqeta_client.models.card_reorder_request import CardReorderRequest
from marqeta_client.models.card_request import CardRequest
from marqeta_client.models.card_response import CardResponse
from marqeta_client.models.card_security_code_verification import CardSecurityCodeVerification
from marqeta_client.models.card_swap_hash import CardSwapHash
from marqeta_client.models.card_transition_list_response import CardTransitionListResponse
from marqeta_client.models.card_transition_request import CardTransitionRequest
from marqeta_client.models.card_transition_response import CardTransitionResponse
from marqeta_client.models.card_update_request import CardUpdateRequest
from marqeta_client.models.card_validation_request import CardValidationRequest
from marqeta_client.models.card_validation_response import CardValidationResponse
from marqeta_client.models.cardholder_address_list_response import CardholderAddressListResponse
from marqeta_client.models.cardholder_address_response import CardholderAddressResponse
from marqeta_client.models.cardholder_authentication_data import CardholderAuthenticationData
from marqeta_client.models.cardholder_balance import CardholderBalance
from marqeta_client.models.cardholder_balances import CardholderBalances
from marqeta_client.models.cardholder_metadata import CardholderMetadata
from marqeta_client.models.cardholder_msa_balance import CardholderMsaBalance
from marqeta_client.models.cardholder_note_request_model import CardholderNoteRequestModel
from marqeta_client.models.cardholder_note_response_model import CardholderNoteResponseModel
from marqeta_client.models.cardholder_note_update_request_model import CardholderNoteUpdateRequestModel
from marqeta_client.models.carrier import Carrier
from marqeta_client.models.chargeback_allocation_ack_request import ChargebackAllocationAckRequest
from marqeta_client.models.chargeback_funding_source_model import ChargebackFundingSourceModel
from marqeta_client.models.chargeback_funding_source_model_all_of import ChargebackFundingSourceModelAllOf
from marqeta_client.models.chargeback_list_response import ChargebackListResponse
from marqeta_client.models.chargeback_request import ChargebackRequest
from marqeta_client.models.chargeback_response import ChargebackResponse
from marqeta_client.models.chargeback_transition_list_response import ChargebackTransitionListResponse
from marqeta_client.models.chargeback_transition_request import ChargebackTransitionRequest
from marqeta_client.models.chargeback_transition_response import ChargebackTransitionResponse
from marqeta_client.models.chargeback_update_request import ChargebackUpdateRequest
from marqeta_client.models.clearing_and_settlement import ClearingAndSettlement
from marqeta_client.models.clearing_file import ClearingFile
from marqeta_client.models.clearing_file_request import ClearingFileRequest
from marqeta_client.models.clearing_file_response import ClearingFileResponse
from marqeta_client.models.clearing_model import ClearingModel
from marqeta_client.models.clearing_retry_model import ClearingRetryModel
from marqeta_client.models.client_access_token_request import ClientAccessTokenRequest
from marqeta_client.models.client_access_token_response import ClientAccessTokenResponse
from marqeta_client.models.commando_mode_enables import CommandoModeEnables
from marqeta_client.models.commando_mode_list_response import CommandoModeListResponse
from marqeta_client.models.commando_mode_nested_transition import CommandoModeNestedTransition
from marqeta_client.models.commando_mode_request import CommandoModeRequest
from marqeta_client.models.commando_mode_response import CommandoModeResponse
from marqeta_client.models.commando_mode_transition_list_response import CommandoModeTransitionListResponse
from marqeta_client.models.commando_mode_transition_request import CommandoModeTransitionRequest
from marqeta_client.models.commando_mode_transition_response import CommandoModeTransitionResponse
from marqeta_client.models.commando_mode_update_request import CommandoModeUpdateRequest
from marqeta_client.models.control_token_request import ControlTokenRequest
from marqeta_client.models.control_token_response import ControlTokenResponse
from marqeta_client.models.create_cache_request_entry import CreateCacheRequestEntry
from marqeta_client.models.create_caches_request import CreateCachesRequest
from marqeta_client.models.create_caches_response import CreateCachesResponse
from marqeta_client.models.cron_job_info import CronJobInfo
from marqeta_client.models.currency_conversion import CurrencyConversion
from marqeta_client.models.customer_due_diligence_request import CustomerDueDiligenceRequest
from marqeta_client.models.customer_due_diligence_response import CustomerDueDiligenceResponse
from marqeta_client.models.customer_due_diligence_update_request import CustomerDueDiligenceUpdateRequest
from marqeta_client.models.dda_request import DDARequest
from marqeta_client.models.deposit_account_info import DepositAccountInfo
from marqeta_client.models.deposit_account_info_response import DepositAccountInfoResponse
from marqeta_client.models.deposit_account_response import DepositAccountResponse
from marqeta_client.models.deposit_account_update_request import DepositAccountUpdateRequest
from marqeta_client.models.deposit_deposit_response import DepositDepositResponse
from marqeta_client.models.device import Device
from marqeta_client.models.digital_wallet_android_pay_provision_request import DigitalWalletAndroidPayProvisionRequest
from marqeta_client.models.digital_wallet_android_pay_provision_response import DigitalWalletAndroidPayProvisionResponse
from marqeta_client.models.digital_wallet_apple_pay_provision_request import DigitalWalletApplePayProvisionRequest
from marqeta_client.models.digital_wallet_apple_pay_provision_response import DigitalWalletApplePayProvisionResponse
from marqeta_client.models.digital_wallet_samsung_pay_provision_request import DigitalWalletSamsungPayProvisionRequest
from marqeta_client.models.digital_wallet_samsung_pay_provision_response import DigitalWalletSamsungPayProvisionResponse
from marqeta_client.models.digital_wallet_token import DigitalWalletToken
from marqeta_client.models.digital_wallet_token_address_verification import DigitalWalletTokenAddressVerification
from marqeta_client.models.digital_wallet_token_device import DigitalWalletTokenDevice
from marqeta_client.models.digital_wallet_token_hash import DigitalWalletTokenHash
from marqeta_client.models.digital_wallet_token_list_response import DigitalWalletTokenListResponse
from marqeta_client.models.digital_wallet_token_metadata import DigitalWalletTokenMetadata
from marqeta_client.models.digital_wallet_token_requestor_map_model import DigitalWalletTokenRequestorMapModel
from marqeta_client.models.digital_wallet_token_requestor_map_update_model import DigitalWalletTokenRequestorMapUpdateModel
from marqeta_client.models.digital_wallet_token_transition_list_response import DigitalWalletTokenTransitionListResponse
from marqeta_client.models.digital_wallet_token_transition_request import DigitalWalletTokenTransitionRequest
from marqeta_client.models.digital_wallet_token_transition_response import DigitalWalletTokenTransitionResponse
from marqeta_client.models.digital_wallet_token_wallet_provider import DigitalWalletTokenWalletProvider
from marqeta_client.models.digital_wallet_tokenization import DigitalWalletTokenization
from marqeta_client.models.digital_wallet_x_pay_provision_request import DigitalWalletXPayProvisionRequest
from marqeta_client.models.digital_wallet_x_pay_provision_response import DigitalWalletXPayProvisionResponse
from marqeta_client.models.direct_deposit_account_list_response import DirectDepositAccountListResponse
from marqeta_client.models.direct_deposit_account_request import DirectDepositAccountRequest
from marqeta_client.models.direct_deposit_account_response import DirectDepositAccountResponse
from marqeta_client.models.direct_deposit_account_transition_request import DirectDepositAccountTransitionRequest
from marqeta_client.models.direct_deposit_account_transition_response import DirectDepositAccountTransitionResponse
from marqeta_client.models.direct_deposit_funding_source_model import DirectDepositFundingSourceModel
from marqeta_client.models.direct_deposit_funding_source_model_all_of import DirectDepositFundingSourceModelAllOf
from marqeta_client.models.direct_deposit_list_response import DirectDepositListResponse
from marqeta_client.models.direct_deposit_request import DirectDepositRequest
from marqeta_client.models.direct_deposit_transition_list_response import DirectDepositTransitionListResponse
from marqeta_client.models.direct_deposit_transition_request import DirectDepositTransitionRequest
from marqeta_client.models.direct_deposit_transition_response import DirectDepositTransitionResponse
from marqeta_client.models.dispute_model import DisputeModel
from marqeta_client.models.dispute_transaction_request import DisputeTransactionRequest
from marqeta_client.models.early_funds_request_model import EarlyFundsRequestModel
from marqeta_client.models.echo_ping_request import EchoPingRequest
from marqeta_client.models.echo_ping_response import EchoPingResponse
from marqeta_client.models.error_message_from_web_push_provisioning_request import ErrorMessageFromWebPushProvisioningRequest
from marqeta_client.models.expiration_offset import ExpirationOffset
from marqeta_client.models.fee import Fee
from marqeta_client.models.fee_detail import FeeDetail
from marqeta_client.models.fee_list_response import FeeListResponse
from marqeta_client.models.fee_model import FeeModel
from marqeta_client.models.fee_request import FeeRequest
from marqeta_client.models.fee_transfer_request import FeeTransferRequest
from marqeta_client.models.fee_transfer_response import FeeTransferResponse
from marqeta_client.models.fee_update_request import FeeUpdateRequest
from marqeta_client.models.file_processing_request import FileProcessingRequest
from marqeta_client.models.file_processing_response import FileProcessingResponse
from marqeta_client.models.financial_request_model import FinancialRequestModel
from marqeta_client.models.fraud_stream_request import FraudStreamRequest
from marqeta_client.models.fraud_view import FraudView
from marqeta_client.models.fulfillment_address_request import FulfillmentAddressRequest
from marqeta_client.models.fulfillment_address_response import FulfillmentAddressResponse
from marqeta_client.models.fulfillment_request import FulfillmentRequest
from marqeta_client.models.fulfillment_response import FulfillmentResponse
from marqeta_client.models.funding import Funding
from marqeta_client.models.funding_account_list_response import FundingAccountListResponse
from marqeta_client.models.funding_account_response_model import FundingAccountResponseModel
from marqeta_client.models.funding_request_model import FundingRequestModel
from marqeta_client.models.funding_response_model import FundingResponseModel
from marqeta_client.models.funding_source_model import FundingSourceModel
from marqeta_client.models.funding_tranlog import FundingTranlog
from marqeta_client.models.gl_entry import GLEntry
from marqeta_client.models.gpa import GPA
from marqeta_client.models.gpa_unload_list_response import GPAUnloadListResponse
from marqeta_client.models.gateway_clearing_request import GatewayClearingRequest
from marqeta_client.models.gateway_log_model import GatewayLogModel
from marqeta_client.models.gateway_program_custom_header_update_request import GatewayProgramCustomHeaderUpdateRequest
from marqeta_client.models.gateway_program_funding_source_request import GatewayProgramFundingSourceRequest
from marqeta_client.models.gateway_program_funding_source_response import GatewayProgramFundingSourceResponse
from marqeta_client.models.gateway_program_funding_source_update_request import GatewayProgramFundingSourceUpdateRequest
from marqeta_client.models.gateway_program_version_update_request import GatewayProgramVersionUpdateRequest
from marqeta_client.models.gateway_response import GatewayResponse
from marqeta_client.models.gatewaylog import Gatewaylog
from marqeta_client.models.gl_transaction_request import GlTransactionRequest
from marqeta_client.models.gpa_request import GpaRequest
from marqeta_client.models.gpa_response import GpaResponse
from marqeta_client.models.gpa_returns import GpaReturns
from marqeta_client.models.health_check_result import HealthCheckResult
from marqeta_client.models.hold_increase import HoldIncrease
from marqeta_client.models.identification_request_model import IdentificationRequestModel
from marqeta_client.models.identification_response_model import IdentificationResponseModel
from marqeta_client.models.images import Images
from marqeta_client.models.images_card import ImagesCard
from marqeta_client.models.images_carrier import ImagesCarrier
from marqeta_client.models.images_carrier_return_window import ImagesCarrierReturnWindow
from marqeta_client.models.images_signature import ImagesSignature
from marqeta_client.models.in_app_provisioning import InAppProvisioning
from marqeta_client.models.installment_payment import InstallmentPayment
from marqeta_client.models.internal_account import InternalAccount
from marqeta_client.models.internal_address_verification_request import InternalAddressVerificationRequest
from marqeta_client.models.internal_auth_control_request import InternalAuthControlRequest
from marqeta_client.models.internal_authorization_transaction import InternalAuthorizationTransaction
from marqeta_client.models.internal_card import InternalCard
from marqeta_client.models.internal_card_product import InternalCardProduct
from marqeta_client.models.internal_configs_request import InternalConfigsRequest
from marqeta_client.models.internal_configs_response import InternalConfigsResponse
from marqeta_client.models.internal_crypto_key import InternalCryptoKey
from marqeta_client.models.internal_crypto_key_request import InternalCryptoKeyRequest
from marqeta_client.models.internal_crypto_key_request_model import InternalCryptoKeyRequestModel
from marqeta_client.models.internal_crypto_key_response import InternalCryptoKeyResponse
from marqeta_client.models.internal_deposit_account_information import InternalDepositAccountInformation
from marqeta_client.models.internal_digital_wallet import InternalDigitalWallet
from marqeta_client.models.internal_digital_wallet_token import InternalDigitalWalletToken
from marqeta_client.models.internal_find_original_request import InternalFindOriginalRequest
from marqeta_client.models.internal_find_original_response import InternalFindOriginalResponse
from marqeta_client.models.internal_funding_source import InternalFundingSource
from marqeta_client.models.internal_gpa_order import InternalGPAOrder
from marqeta_client.models.internal_gateway_log import InternalGatewayLog
from marqeta_client.models.internal_gateway_merchant import InternalGatewayMerchant
from marqeta_client.models.internal_gateway_response import InternalGatewayResponse
from marqeta_client.models.internal_network_transaction_request import InternalNetworkTransactionRequest
from marqeta_client.models.internal_sys_config import InternalSysConfig
from marqeta_client.models.internal_transaction_data_model import InternalTransactionDataModel
from marqeta_client.models.internal_transaction_message import InternalTransactionMessage
from marqeta_client.models.internal_transaction_response import InternalTransactionResponse
from marqeta_client.models.internal_user import InternalUser
from marqeta_client.models.internal_user_transaction_request import InternalUserTransactionRequest
from marqeta_client.models.iso8583_digital_wallet_token import Iso8583DigitalWalletToken
from marqeta_client.models.issuer import Issuer
from marqeta_client.models.issuer_fraud_view import IssuerFraudView
from marqeta_client.models.jit_address_verification import JitAddressVerification
from marqeta_client.models.jit_funding import JitFunding
from marqeta_client.models.jit_funding_api import JitFundingApi
from marqeta_client.models.jit_funding_paymentcard_funding_source import JitFundingPaymentcardFundingSource
from marqeta_client.models.jit_funding_program_funding_source import JitFundingProgramFundingSource
from marqeta_client.models.jit_funding_programgateway_funding_source import JitFundingProgramgatewayFundingSource
from marqeta_client.models.jit_program_response import JitProgramResponse
from marqeta_client.models.kyc_list_response import KYCListResponse
from marqeta_client.models.kyc_submit_answers_request_model import KYCSubmitAnswersRequestModel
from marqeta_client.models.kyc_answer import KycAnswer
from marqeta_client.models.kyc_request import KycRequest
from marqeta_client.models.kyc_response import KycResponse
from marqeta_client.models.link import Link
from marqeta_client.models.linked_account_balance_response import LinkedAccountBalanceResponse
from marqeta_client.models.load_rule_list_response import LoadRuleListResponse
from marqeta_client.models.load_velocity_model import LoadVelocityModel
from marqeta_client.models.login_request_model import LoginRequestModel
from marqeta_client.models.login_response_model import LoginResponseModel
from marqeta_client.models.mcc_config import MCCConfig
from marqeta_client.models.mcc_group_list_response import MCCGroupListResponse
from marqeta_client.models.msa import MSA
from marqeta_client.models.manual_entry import ManualEntry
from marqeta_client.models.mcc_group_model import MccGroupModel
from marqeta_client.models.mcc_group_update_model import MccGroupUpdateModel
from marqeta_client.models.merchant_card_request import MerchantCardRequest
from marqeta_client.models.merchant_group_list_response import MerchantGroupListResponse
from marqeta_client.models.merchant_group_request import MerchantGroupRequest
from marqeta_client.models.merchant_group_response import MerchantGroupResponse
from marqeta_client.models.merchant_group_update_request import MerchantGroupUpdateRequest
from marqeta_client.models.merchant_response_model import MerchantResponseModel
from marqeta_client.models.merchant_scope import MerchantScope
from marqeta_client.models.min_offset import MinOffset
from marqeta_client.models.money_in_transaction import MoneyInTransaction
from marqeta_client.models.money_model import MoneyModel
from marqeta_client.models.monitor_response import MonitorResponse
from marqeta_client.models.msa_aggregated_balances import MsaAggregatedBalances
from marqeta_client.models.msa_balances import MsaBalances
from marqeta_client.models.msa_order_response import MsaOrderResponse
from marqeta_client.models.msa_returns import MsaReturns
from marqeta_client.models.network import Network
from marqeta_client.models.network_account_intelligence_score import NetworkAccountIntelligenceScore
from marqeta_client.models.network_fee_model import NetworkFeeModel
from marqeta_client.models.network_fraud_view import NetworkFraudView
from marqeta_client.models.network_metadata import NetworkMetadata
from marqeta_client.models.offer_model import OfferModel
from marqeta_client.models.offer_order_aggregated_balances import OfferOrderAggregatedBalances
from marqeta_client.models.offer_order_balances import OfferOrderBalances
from marqeta_client.models.offer_order_response import OfferOrderResponse
from marqeta_client.models.one_time_request_model import OneTimeRequestModel
from marqeta_client.models.order_scope import OrderScope
from marqeta_client.models.original_credit import OriginalCredit
from marqeta_client.models.original_credit_sender_data import OriginalCreditSenderData
from marqeta_client.models.original_data_elements import OriginalDataElements
from marqeta_client.models.orignalcredit_request_model import OrignalcreditRequestModel
from marqeta_client.models.other_poi import OtherPoi
from marqeta_client.models.ptc_address import PTCAddress
from marqeta_client.models.ptc_phone import PTCPhone
from marqeta_client.models.ptc_soft_descriptor import PTCSoftDescriptor
from marqeta_client.models.pagination import Pagination
from marqeta_client.models.pan_request import PanRequest
from marqeta_client.models.pan_response import PanResponse
from marqeta_client.models.password_update_model import PasswordUpdateModel
from marqeta_client.models.payment_card_funding_source_model import PaymentCardFundingSourceModel
from marqeta_client.models.payment_card_funding_source_model_all_of import PaymentCardFundingSourceModelAllOf
from marqeta_client.models.payment_card_response_model import PaymentCardResponseModel
from marqeta_client.models.peer_transfer_request import PeerTransferRequest
from marqeta_client.models.peer_transfer_response import PeerTransferResponse
from marqeta_client.models.pin_request import PinRequest
from marqeta_client.models.pin_reveal_request import PinRevealRequest
from marqeta_client.models.ping_response import PingResponse
from marqeta_client.models.ping_response_extended import PingResponseExtended
from marqeta_client.models.poi import Poi
from marqeta_client.models.pos import Pos
from marqeta_client.models.pre_kyc_controls import PreKycControls
from marqeta_client.models.preceding_transaction import PrecedingTransaction
from marqeta_client.models.primary_contact_info_model import PrimaryContactInfoModel
from marqeta_client.models.program import Program
from marqeta_client.models.program_funding_source_ach_update_request import ProgramFundingSourceAchUpdateRequest
from marqeta_client.models.program_funding_source_list_response import ProgramFundingSourceListResponse
from marqeta_client.models.program_funding_source_model import ProgramFundingSourceModel
from marqeta_client.models.program_funding_source_request import ProgramFundingSourceRequest
from marqeta_client.models.program_funding_source_response import ProgramFundingSourceResponse
from marqeta_client.models.program_funding_source_update_request import ProgramFundingSourceUpdateRequest
from marqeta_client.models.program_gateway_funding_source_model import ProgramGatewayFundingSourceModel
from marqeta_client.models.program_reserve_account_balance import ProgramReserveAccountBalance
from marqeta_client.models.program_reserve_deposit_request import ProgramReserveDepositRequest
from marqeta_client.models.program_reserve_transaction_clearing_request import ProgramReserveTransactionClearingRequest
from marqeta_client.models.program_reserve_transaction_list_response import ProgramReserveTransactionListResponse
from marqeta_client.models.program_reserve_transaction_request import ProgramReserveTransactionRequest
from marqeta_client.models.program_reserve_transaction_response import ProgramReserveTransactionResponse
from marqeta_client.models.program_transfer import ProgramTransfer
from marqeta_client.models.program_transfer_list_response import ProgramTransferListResponse
from marqeta_client.models.program_transfer_response import ProgramTransferResponse
from marqeta_client.models.program_transfer_type_list_response import ProgramTransferTypeListResponse
from marqeta_client.models.program_transfer_type_request import ProgramTransferTypeRequest
from marqeta_client.models.program_transfer_type_response import ProgramTransferTypeResponse
from marqeta_client.models.provisioning_controls import ProvisioningControls
from marqeta_client.models.publish_eftto_trancache_and_webhook_queue import PublishEFTToTrancacheAndWebhookQueue
from marqeta_client.models.publish_transfer_response import PublishTransferResponse
from marqeta_client.models.pull_from_card_transfer_response import PullFromCardTransferResponse
from marqeta_client.models.push_to_card_disburse_list_response import PushToCardDisburseListResponse
from marqeta_client.models.push_to_card_disburse_request import PushToCardDisburseRequest
from marqeta_client.models.push_to_card_disbursement_response import PushToCardDisbursementResponse
from marqeta_client.models.push_to_card_list_response import PushToCardListResponse
from marqeta_client.models.push_to_card_request import PushToCardRequest
from marqeta_client.models.push_to_card_response import PushToCardResponse
from marqeta_client.models.real_time_fee_assessment import RealTimeFeeAssessment
from marqeta_client.models.real_time_fee_assessment_request import RealTimeFeeAssessmentRequest
from marqeta_client.models.real_time_fee_group import RealTimeFeeGroup
from marqeta_client.models.real_time_fee_group_create_request import RealTimeFeeGroupCreateRequest
from marqeta_client.models.real_time_fee_group_list_response import RealTimeFeeGroupListResponse
from marqeta_client.models.real_time_fee_group_request import RealTimeFeeGroupRequest
from marqeta_client.models.real_time_standin_criteria import RealTimeStandinCriteria
from marqeta_client.models.replacement_amount import ReplacementAmount
from marqeta_client.models.report_request import ReportRequest
from marqeta_client.models.request_for_apple_pay_wpp_jwt import RequestForApplePayWppJWT
from marqeta_client.models.request_for_wpp_parameters import RequestForWppParameters
from marqeta_client.models.reset_user_password_email_model import ResetUserPasswordEmailModel
from marqeta_client.models.reset_user_password_model import ResetUserPasswordModel
from marqeta_client.models.response import Response
from marqeta_client.models.result import Result
from marqeta_client.models.result_code import ResultCode
from marqeta_client.models.result_code_info import ResultCodeInfo
from marqeta_client.models.reversal_model import ReversalModel
from marqeta_client.models.risk_assessment import RiskAssessment
from marqeta_client.models.riskcontrol_tags import RiskcontrolTags
from marqeta_client.models.samsung_push_tokenize_request_data import SamsungPushTokenizeRequestData
from marqeta_client.models.selective_auth import SelectiveAuth
from marqeta_client.models.sending_provisioning_data_to_google_pay_backend_request import SendingProvisioningDataToGooglePayBackendRequest
from marqeta_client.models.settlement_data import SettlementData
from marqeta_client.models.shipping import Shipping
from marqeta_client.models.shipping_information_response import ShippingInformationResponse
from marqeta_client.models.simulate_incremental_auth_request import SimulateIncrementalAuthRequest
from marqeta_client.models.simulate_pin_debit_auth_request import SimulatePinDebitAuthRequest
from marqeta_client.models.simulation_response_model import SimulationResponseModel
from marqeta_client.models.special import Special
from marqeta_client.models.spend_control_association import SpendControlAssociation
from marqeta_client.models.ssn_response_model import SsnResponseModel
from marqeta_client.models.store_response_model import StoreResponseModel
from marqeta_client.models.strong_customer_authentication_limits import StrongCustomerAuthenticationLimits
from marqeta_client.models.taba_pay_accounts import TabaPayAccounts
from marqeta_client.models.taba_pay_add_payment_instrument_request import TabaPayAddPaymentInstrumentRequest
from marqeta_client.models.taba_pay_card import TabaPayCard
from marqeta_client.models.taba_pay_name import TabaPayName
from marqeta_client.models.taba_pay_owner import TabaPayOwner
from marqeta_client.models.taba_pay_payout_request import TabaPayPayoutRequest
from marqeta_client.models.taba_pay_push import TabaPayPush
from marqeta_client.models.tabapay_ptc_address import TabapayPTCAddress
from marqeta_client.models.tabapay_soft_descriptor import TabapaySoftDescriptor
from marqeta_client.models.tabapay_soft_descriptor_phone import TabapaySoftDescriptorPhone
from marqeta_client.models.tag import Tag
from marqeta_client.models.terminal_model import TerminalModel
from marqeta_client.models.text import Text
from marqeta_client.models.text_value import TextValue
from marqeta_client.models.token_request import TokenRequest
from marqeta_client.models.token_service_provider import TokenServiceProvider
from marqeta_client.models.token_update_request import TokenUpdateRequest
from marqeta_client.models.track1_data import Track1Data
from marqeta_client.models.tran_log_attribute_request import TranLogAttributeRequest
from marqeta_client.models.tranlog_token_with_injectable_domain_data_to_publish_to_trancache_and_webhook_queue import TranlogTokenWithInjectableDomainDataToPublishToTrancacheAndWebhookQueue
from marqeta_client.models.transaction import Transaction
from marqeta_client.models.transaction_cache_payload_nullification_model import TransactionCachePayloadNullificationModel
from marqeta_client.models.transaction_card_acceptor import TransactionCardAcceptor
from marqeta_client.models.transaction_card_acceptor_view_model_v1 import TransactionCardAcceptorViewModelV1
from marqeta_client.models.transaction_controls import TransactionControls
from marqeta_client.models.transaction_metadata import TransactionMetadata
from marqeta_client.models.transaction_model import TransactionModel
from marqeta_client.models.transaction_model_list_response import TransactionModelListResponse
from marqeta_client.models.transaction_options import TransactionOptions
from marqeta_client.models.transaction_update_model import TransactionUpdateModel
from marqeta_client.models.transit import Transit
from marqeta_client.models.triggered_rule import TriggeredRule
from marqeta_client.models.unload_request_model import UnloadRequestModel
from marqeta_client.models.update_business_check_request_request import UpdateBusinessCheckRequestRequest
from marqeta_client.models.update_system_health import UpdateSystemHealth
from marqeta_client.models.user_association import UserAssociation
from marqeta_client.models.user_card_holder_list_response import UserCardHolderListResponse
from marqeta_client.models.user_card_holder_response import UserCardHolderResponse
from marqeta_client.models.user_card_holder_search_model import UserCardHolderSearchModel
from marqeta_client.models.user_card_holder_update_model import UserCardHolderUpdateModel
from marqeta_client.models.user_stip_balance_request import UserStipBalanceRequest
from marqeta_client.models.user_stip_balance_response import UserStipBalanceResponse
from marqeta_client.models.user_transition_list_response import UserTransitionListResponse
from marqeta_client.models.user_transition_request import UserTransitionRequest
from marqeta_client.models.user_transition_response import UserTransitionResponse
from marqeta_client.models.user_validation_request import UserValidationRequest
from marqeta_client.models.user_validation_response import UserValidationResponse
from marqeta_client.models.validations_request import ValidationsRequest
from marqeta_client.models.validations_response import ValidationsResponse
from marqeta_client.models.velocity_cache import VelocityCache
from marqeta_client.models.velocity_control_balance_list_response import VelocityControlBalanceListResponse
from marqeta_client.models.velocity_control_balance_response import VelocityControlBalanceResponse
from marqeta_client.models.velocity_control_check_request import VelocityControlCheckRequest
from marqeta_client.models.velocity_control_check_response import VelocityControlCheckResponse
from marqeta_client.models.velocity_control_list_response import VelocityControlListResponse
from marqeta_client.models.velocity_control_request import VelocityControlRequest
from marqeta_client.models.velocity_control_response import VelocityControlResponse
from marqeta_client.models.velocity_control_update_request import VelocityControlUpdateRequest
from marqeta_client.models.wallet_provider_card_on_file import WalletProviderCardOnFile
from marqeta_client.models.wallet_provider_profile import WalletProviderProfile
from marqeta_client.models.web_push_provisioning import WebPushProvisioning
from marqeta_client.models.web_push_provisioning_apple_pay_jws_header import WebPushProvisioningApplePayJWSHeader
from marqeta_client.models.web_push_provisioning_apple_pay_jws_model import WebPushProvisioningApplePayJWSModel
from marqeta_client.models.web_push_provisioning_apple_pay_jwt_response import WebPushProvisioningApplePayJWTResponse
from marqeta_client.models.webhook import Webhook
from marqeta_client.models.webhook_base_model import WebhookBaseModel
from marqeta_client.models.webhook_config_model import WebhookConfigModel
from marqeta_client.models.webhook_ping_model import WebhookPingModel
from marqeta_client.models.webhook_request_model import WebhookRequestModel
from marqeta_client.models.webhook_response_model import WebhookResponseModel
from marqeta_client.models.webhook_response_model_list_response import WebhookResponseModelListResponse
from marqeta_client.models.webhook_update_custom_header_request import WebhookUpdateCustomHeaderRequest
from marqeta_client.models.withdrawal_request_model import WithdrawalRequestModel
from marqeta_client.models.xpay_push_tokenize_request_data import XpayPushTokenizeRequestData



# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Dict, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, validator
from marqeta_client.models.internal_card_product import InternalCardProduct
from marqeta_client.models.internal_user import InternalUser

class InternalCard(BaseModel):
    """
    InternalCard
    """
    hash: Optional[StrictStr] = None
    kid: Optional[StrictStr] = None
    secure_data: Optional[StrictStr] = Field(None, alias="secureData")
    service_code: Optional[StrictStr] = Field(None, alias="serviceCode")
    id: StrictInt = ...
    token: StrictStr = ...
    user: InternalUser = ...
    card_product: InternalCardProduct = ...
    last_four: StrictStr = ...
    expiration_time: Optional[datetime] = None
    state: Optional[StrictStr] = None
    metadata: Optional[Dict[str, StrictStr]] = None
    card_pin_block: Optional[StrictStr] = None
    contactless_consecutive_total_spend: Optional[Union[StrictFloat, StrictInt]] = None
    contactless_consecutive_count: Optional[StrictInt] = None
    lvp_consecutive_total_spend: Optional[Union[StrictFloat, StrictInt]] = None
    lvp_consecutive_count: Optional[StrictInt] = None
    is_offline_pin_set_required: Optional[StrictBool] = None
    __properties = ["hash", "kid", "secureData", "serviceCode", "id", "token", "user", "card_product", "last_four", "expiration_time", "state", "metadata", "card_pin_block", "contactless_consecutive_total_spend", "contactless_consecutive_count", "lvp_consecutive_total_spend", "lvp_consecutive_count", "is_offline_pin_set_required"]

    @validator('state')
    def state_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('ACTIVE', 'SUSPENDED', 'TERMINATED', 'UNSUPPORTED', 'UNACTIVATED', 'LIMITED'):
            raise ValueError("must be one of enum values ('ACTIVE', 'SUSPENDED', 'TERMINATED', 'UNSUPPORTED', 'UNACTIVATED', 'LIMITED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalCard:
        """Create an instance of InternalCard from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_product
        if self.card_product:
            _dict['card_product'] = self.card_product.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalCard:
        """Create an instance of InternalCard from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalCard.parse_obj(obj)

        _obj = InternalCard.parse_obj({
            "hash": obj.get("hash"),
            "kid": obj.get("kid"),
            "secure_data": obj.get("secureData"),
            "service_code": obj.get("serviceCode"),
            "id": obj.get("id"),
            "token": obj.get("token"),
            "user": InternalUser.from_dict(obj.get("user")) if obj.get("user") is not None else None,
            "card_product": InternalCardProduct.from_dict(obj.get("card_product")) if obj.get("card_product") is not None else None,
            "last_four": obj.get("last_four"),
            "expiration_time": obj.get("expiration_time"),
            "state": obj.get("state"),
            "metadata": obj.get("metadata"),
            "card_pin_block": obj.get("card_pin_block"),
            "contactless_consecutive_total_spend": obj.get("contactless_consecutive_total_spend"),
            "contactless_consecutive_count": obj.get("contactless_consecutive_count"),
            "lvp_consecutive_total_spend": obj.get("lvp_consecutive_total_spend"),
            "lvp_consecutive_count": obj.get("lvp_consecutive_count"),
            "is_offline_pin_set_required": obj.get("is_offline_pin_set_required")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictBool, constr, validator

class JitFundingProgramFundingSource(BaseModel):
    """
    JitFundingProgramFundingSource
    """
    enabled: Optional[StrictBool] = False
    funding_source_token: Optional[constr(strict=True, max_length=36, min_length=0)] = Field(None, description="required if enabled")
    refunds_destination: Optional[constr(strict=True, max_length=50, min_length=0)] = None
    __properties = ["enabled", "funding_source_token", "refunds_destination"]

    @validator('refunds_destination')
    def refunds_destination_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('PROGRAM_FUNDING_SOURCE', 'GPA', 'WATERFALL'):
            raise ValueError("must be one of enum values ('PROGRAM_FUNDING_SOURCE', 'GPA', 'WATERFALL')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> JitFundingProgramFundingSource:
        """Create an instance of JitFundingProgramFundingSource from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> JitFundingProgramFundingSource:
        """Create an instance of JitFundingProgramFundingSource from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return JitFundingProgramFundingSource.parse_obj(obj)

        _obj = JitFundingProgramFundingSource.parse_obj({
            "enabled": obj.get("enabled") if obj.get("enabled") is not None else False,
            "funding_source_token": obj.get("funding_source_token"),
            "refunds_destination": obj.get("refunds_destination")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, StrictBool, StrictFloat, StrictInt, StrictStr, constr
from marqeta_client.models.real_time_fee_assessment_request import RealTimeFeeAssessmentRequest

class FeeUpdateRequest(BaseModel):
    """
    FeeUpdateRequest
    """
    name: Optional[constr(strict=True, max_length=50, min_length=1)] = None
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    tags: Optional[constr(strict=True, max_length=255, min_length=1)] = None
    currency_code: Optional[StrictStr] = None
    active: Optional[StrictBool] = True
    real_time_assessment: Optional[RealTimeFeeAssessmentRequest] = None
    __properties = ["name", "amount", "tags", "currency_code", "active", "real_time_assessment"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> FeeUpdateRequest:
        """Create an instance of FeeUpdateRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of real_time_assessment
        if self.real_time_assessment:
            _dict['real_time_assessment'] = self.real_time_assessment.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> FeeUpdateRequest:
        """Create an instance of FeeUpdateRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return FeeUpdateRequest.parse_obj(obj)

        _obj = FeeUpdateRequest.parse_obj({
            "name": obj.get("name"),
            "amount": obj.get("amount"),
            "tags": obj.get("tags"),
            "currency_code": obj.get("currency_code"),
            "active": obj.get("active") if obj.get("active") is not None else True,
            "real_time_assessment": RealTimeFeeAssessmentRequest.from_dict(obj.get("real_time_assessment")) if obj.get("real_time_assessment") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, validator

class Pos(BaseModel):
    """
    Pos
    """
    pan_entry_mode: Optional[StrictStr] = None
    pin_entry_mode: Optional[StrictStr] = None
    terminal_id: Optional[StrictStr] = None
    terminal_attendance: Optional[StrictStr] = None
    terminal_location: Optional[StrictStr] = None
    card_holder_presence: Optional[StrictBool] = False
    cardholder_authentication_method: Optional[StrictStr] = None
    card_presence: Optional[StrictBool] = False
    pin_present: Optional[StrictBool] = False
    terminal_type: Optional[StrictStr] = None
    card_data_input_capability: Optional[StrictStr] = None
    country_code: Optional[StrictStr] = None
    zip: Optional[StrictStr] = None
    partial_approval_capable: Optional[StrictBool] = False
    purchase_amount_only: Optional[StrictBool] = False
    is_recurring: Optional[StrictBool] = False
    is_installment: Optional[StrictBool] = False
    __properties = ["pan_entry_mode", "pin_entry_mode", "terminal_id", "terminal_attendance", "terminal_location", "card_holder_presence", "cardholder_authentication_method", "card_presence", "pin_present", "terminal_type", "card_data_input_capability", "country_code", "zip", "partial_approval_capable", "purchase_amount_only", "is_recurring", "is_installment"]

    @validator('pan_entry_mode')
    def pan_entry_mode_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('UNKNOWN', 'MANUAL', 'MAG_STRIPE', 'MAG_STRIPE_CONTACTLESS', 'BAR_CODE', 'OCR', 'MICR', 'CHIP', 'CHIP_CONTACTLESS', 'CARD_ON_FILE', 'CHIP_FALLBACK', 'OTHER'):
            raise ValueError("must be one of enum values ('UNKNOWN', 'MANUAL', 'MAG_STRIPE', 'MAG_STRIPE_CONTACTLESS', 'BAR_CODE', 'OCR', 'MICR', 'CHIP', 'CHIP_CONTACTLESS', 'CARD_ON_FILE', 'CHIP_FALLBACK', 'OTHER')")
        return v

    @validator('pin_entry_mode')
    def pin_entry_mode_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('UNKNOWN', 'TRUE', 'FALSE', 'DEFECTIVE'):
            raise ValueError("must be one of enum values ('UNKNOWN', 'TRUE', 'FALSE', 'DEFECTIVE')")
        return v

    @validator('terminal_attendance')
    def terminal_attendance_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('UNSPECIFIED', 'ATTENDED', 'UNATTENDED', 'NO_TERMINAL'):
            raise ValueError("must be one of enum values ('UNSPECIFIED', 'ATTENDED', 'UNATTENDED', 'NO_TERMINAL')")
        return v

    @validator('terminal_location')
    def terminal_location_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('ON_PREMISE', 'OFF_PREMISE_MERCHANT', 'OFF_PREMISE_CARDHOLDER', 'NO_TERMINAL'):
            raise ValueError("must be one of enum values ('ON_PREMISE', 'OFF_PREMISE_MERCHANT', 'OFF_PREMISE_CARDHOLDER', 'NO_TERMINAL')")
        return v

    @validator('cardholder_authentication_method')
    def cardholder_authentication_method_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('UNSPECIFIED', 'NON_AUTHENTICATED', 'SIGNATURE', 'PIN', 'ID_VERIFIED'):
            raise ValueError("must be one of enum values ('UNSPECIFIED', 'NON_AUTHENTICATED', 'SIGNATURE', 'PIN', 'ID_VERIFIED')")
        return v

    @validator('terminal_type')
    def terminal_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('AUTO_DISPENSER_WITH_PIN', 'SELF_SERVICE', 'LIMITED_AMOUNT', 'IN_FLIGHT', 'ECOMMERCE', 'TRANSPONDER'):
            raise ValueError("must be one of enum values ('AUTO_DISPENSER_WITH_PIN', 'SELF_SERVICE', 'LIMITED_AMOUNT', 'IN_FLIGHT', 'ECOMMERCE', 'TRANSPONDER')")
        return v

    @validator('card_data_input_capability')
    def card_data_input_capability_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('UNKNOWN', 'NO_TERMINAL', 'MAG_STRIPE', 'MAG_STRIPE_CONTACTLESS', 'MAG_STRIPE_KEY_ENTRY', 'CHIP', 'CHIP_CONTACTLESS', 'CHIP_MAG_STRIPE', 'CHIP_MAG_STRIPE_KEY_ENTRY', 'KEY_ENTRY', 'OCR', 'MICR', 'BAR_CODE'):
            raise ValueError("must be one of enum values ('UNKNOWN', 'NO_TERMINAL', 'MAG_STRIPE', 'MAG_STRIPE_CONTACTLESS', 'MAG_STRIPE_KEY_ENTRY', 'CHIP', 'CHIP_CONTACTLESS', 'CHIP_MAG_STRIPE', 'CHIP_MAG_STRIPE_KEY_ENTRY', 'KEY_ENTRY', 'OCR', 'MICR', 'BAR_CODE')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Pos:
        """Create an instance of Pos from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Pos:
        """Create an instance of Pos from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Pos.parse_obj(obj)

        _obj = Pos.parse_obj({
            "pan_entry_mode": obj.get("pan_entry_mode"),
            "pin_entry_mode": obj.get("pin_entry_mode"),
            "terminal_id": obj.get("terminal_id"),
            "terminal_attendance": obj.get("terminal_attendance"),
            "terminal_location": obj.get("terminal_location"),
            "card_holder_presence": obj.get("card_holder_presence") if obj.get("card_holder_presence") is not None else False,
            "cardholder_authentication_method": obj.get("cardholder_authentication_method"),
            "card_presence": obj.get("card_presence") if obj.get("card_presence") is not None else False,
            "pin_present": obj.get("pin_present") if obj.get("pin_present") is not None else False,
            "terminal_type": obj.get("terminal_type"),
            "card_data_input_capability": obj.get("card_data_input_capability"),
            "country_code": obj.get("country_code"),
            "zip": obj.get("zip"),
            "partial_approval_capable": obj.get("partial_approval_capable") if obj.get("partial_approval_capable") is not None else False,
            "purchase_amount_only": obj.get("purchase_amount_only") if obj.get("purchase_amount_only") is not None else False,
            "is_recurring": obj.get("is_recurring") if obj.get("is_recurring") is not None else False,
            "is_installment": obj.get("is_installment") if obj.get("is_installment") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, StrictInt, StrictStr
from marqeta_client.models.result_code_info import ResultCodeInfo

class ResultCode(BaseModel):
    """
    ResultCode
    """
    id: Optional[StrictInt] = None
    mnemonic: Optional[StrictStr] = None
    description: Optional[StrictStr] = None
    locales: Optional[Dict[str, ResultCodeInfo]] = None
    __properties = ["id", "mnemonic", "description", "locales"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> ResultCode:
        """Create an instance of ResultCode from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of each value in locales (dict)
        _field_dict = {}
        if self.locales:
            for _key in self.locales:
                if self.locales[_key]:
                    _field_dict[_key] = self.locales[_key].to_dict()
            _dict['locales'] = _field_dict
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> ResultCode:
        """Create an instance of ResultCode from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return ResultCode.parse_obj(obj)

        _obj = ResultCode.parse_obj({
            "id": obj.get("id"),
            "mnemonic": obj.get("mnemonic"),
            "description": obj.get("description"),
            "locales": dict(
                (_k, ResultCodeInfo.from_dict(_v))
                for _k, _v in obj.get("locales").items()
            )
            if obj.get("locales") is not None
            else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, Field, StrictStr, validator
from marqeta_client.models.fulfillment_address_request import FulfillmentAddressRequest

class Shipping(BaseModel):
    """
    Shipping
    """
    method: Optional[StrictStr] = None
    return_address: Optional[FulfillmentAddressRequest] = None
    recipient_address: Optional[FulfillmentAddressRequest] = None
    care_of_line: Optional[StrictStr] = Field(None, description="255 char max")
    __properties = ["method", "return_address", "recipient_address", "care_of_line"]

    @validator('method')
    def method_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('LOCAL_MAIL', 'LOCAL_MAIL_PACKAGE', 'GROUND', 'TWO_DAY', 'OVERNIGHT', 'INTERNATIONAL', 'INTERNATIONAL_PRIORITY', 'LOCAL_PRIORITY', 'FEDEX_EXPEDITED', 'FEDEX_REGULAR', 'UPS_EXPEDITED', 'UPS_REGULAR', 'USPS_EXPEDITED', 'USPS_REGULAR'):
            raise ValueError("must be one of enum values ('LOCAL_MAIL', 'LOCAL_MAIL_PACKAGE', 'GROUND', 'TWO_DAY', 'OVERNIGHT', 'INTERNATIONAL', 'INTERNATIONAL_PRIORITY', 'LOCAL_PRIORITY', 'FEDEX_EXPEDITED', 'FEDEX_REGULAR', 'UPS_EXPEDITED', 'UPS_REGULAR', 'USPS_EXPEDITED', 'USPS_REGULAR')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Shipping:
        """Create an instance of Shipping from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of return_address
        if self.return_address:
            _dict['return_address'] = self.return_address.to_dict()
        # override the default output from pydantic by calling `to_dict()` of recipient_address
        if self.recipient_address:
            _dict['recipient_address'] = self.recipient_address.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> Shipping:
        """Create an instance of Shipping from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return Shipping.parse_obj(obj)

        _obj = Shipping.parse_obj({
            "method": obj.get("method"),
            "return_address": FulfillmentAddressRequest.from_dict(obj.get("return_address")) if obj.get("return_address") is not None else None,
            "recipient_address": FulfillmentAddressRequest.from_dict(obj.get("recipient_address")) if obj.get("recipient_address") is not None else None,
            "care_of_line": obj.get("care_of_line")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json



from pydantic import BaseModel, Field, StrictStr
from marqeta_client.models.web_push_provisioning_apple_pay_jws_header import WebPushProvisioningApplePayJWSHeader

class WebPushProvisioningApplePayJWSModel(BaseModel):
    """
    WebPushProvisioningApplePayJWSModel
    """
    header: WebPushProvisioningApplePayJWSHeader = ...
    protected: StrictStr = Field(..., description="JWS Protected Headers, contains the Header Parameters that are integrity protected by the JWS Signature.")
    payload: StrictStr = Field(..., description="JWS payload which includes the message to be sent.")
    signature: StrictStr = Field(..., description="JWS Signature")
    __properties = ["header", "protected", "payload", "signature"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> WebPushProvisioningApplePayJWSModel:
        """Create an instance of WebPushProvisioningApplePayJWSModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of header
        if self.header:
            _dict['header'] = self.header.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> WebPushProvisioningApplePayJWSModel:
        """Create an instance of WebPushProvisioningApplePayJWSModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return WebPushProvisioningApplePayJWSModel.parse_obj(obj)

        _obj = WebPushProvisioningApplePayJWSModel.parse_obj({
            "header": WebPushProvisioningApplePayJWSHeader.from_dict(obj.get("header")) if obj.get("header") is not None else None,
            "protected": obj.get("protected"),
            "payload": obj.get("payload"),
            "signature": obj.get("signature")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr
from marqeta_client.models.funding import Funding
from marqeta_client.models.msa_aggregated_balances import MsaAggregatedBalances
from marqeta_client.models.msa_balances import MsaBalances

class MsaOrderResponse(BaseModel):
    """
    MsaOrderResponse
    """
    token: Optional[StrictStr] = None
    user_token: Optional[StrictStr] = None
    business_token: Optional[StrictStr] = None
    order_balances: MsaBalances = ...
    purchase_amount: Union[StrictFloat, StrictInt] = ...
    last_transaction_date: datetime = Field(..., description="yyyy-MM-ddThh:mm:ssZ")
    start_date: Optional[datetime] = Field(None, description="yyyy-MM-ddThh:mm:ssZ")
    end_date: Optional[datetime] = Field(None, description="yyyy-MM-ddThh:mm:ssZ")
    currency_code: StrictStr = ...
    active: StrictBool = ...
    reward_amount: Union[StrictFloat, StrictInt] = ...
    reward_trigger_amount: Union[StrictFloat, StrictInt] = ...
    unloaded_amount: Optional[Union[StrictFloat, StrictInt]] = None
    campaign_token: StrictStr = ...
    funding: Funding = ...
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    aggregated_balances: MsaAggregatedBalances = ...
    transaction_token: StrictStr = ...
    __properties = ["token", "user_token", "business_token", "order_balances", "purchase_amount", "last_transaction_date", "start_date", "end_date", "currency_code", "active", "reward_amount", "reward_trigger_amount", "unloaded_amount", "campaign_token", "funding", "created_time", "last_modified_time", "aggregated_balances", "transaction_token"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> MsaOrderResponse:
        """Create an instance of MsaOrderResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of order_balances
        if self.order_balances:
            _dict['order_balances'] = self.order_balances.to_dict()
        # override the default output from pydantic by calling `to_dict()` of funding
        if self.funding:
            _dict['funding'] = self.funding.to_dict()
        # override the default output from pydantic by calling `to_dict()` of aggregated_balances
        if self.aggregated_balances:
            _dict['aggregated_balances'] = self.aggregated_balances.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> MsaOrderResponse:
        """Create an instance of MsaOrderResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return MsaOrderResponse.parse_obj(obj)

        _obj = MsaOrderResponse.parse_obj({
            "token": obj.get("token"),
            "user_token": obj.get("user_token"),
            "business_token": obj.get("business_token"),
            "order_balances": MsaBalances.from_dict(obj.get("order_balances")) if obj.get("order_balances") is not None else None,
            "purchase_amount": obj.get("purchase_amount"),
            "last_transaction_date": obj.get("last_transaction_date"),
            "start_date": obj.get("start_date"),
            "end_date": obj.get("end_date"),
            "currency_code": obj.get("currency_code"),
            "active": obj.get("active") if obj.get("active") is not None else False,
            "reward_amount": obj.get("reward_amount"),
            "reward_trigger_amount": obj.get("reward_trigger_amount"),
            "unloaded_amount": obj.get("unloaded_amount"),
            "campaign_token": obj.get("campaign_token"),
            "funding": Funding.from_dict(obj.get("funding")) if obj.get("funding") is not None else None,
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "aggregated_balances": MsaAggregatedBalances.from_dict(obj.get("aggregated_balances")) if obj.get("aggregated_balances") is not None else None,
            "transaction_token": obj.get("transaction_token")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictBool, StrictStr
from marqeta_client.models.funding_tranlog import FundingTranlog
from marqeta_client.models.internal_authorization_transaction import InternalAuthorizationTransaction
from marqeta_client.models.response import Response

class InternalFindOriginalResponse(BaseModel):
    """
    InternalFindOriginalResponse
    """
    original_found: Optional[StrictBool] = Field(None, alias="originalFound")
    original_tranlog: Optional[InternalAuthorizationTransaction] = None
    funding_transaction: Optional[FundingTranlog] = None
    finder_name: Optional[StrictStr] = None
    context: Optional[Dict[str, StrictStr]] = None
    response: Optional[Response] = None
    __properties = ["originalFound", "original_tranlog", "funding_transaction", "finder_name", "context", "response"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalFindOriginalResponse:
        """Create an instance of InternalFindOriginalResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of original_tranlog
        if self.original_tranlog:
            _dict['original_tranlog'] = self.original_tranlog.to_dict()
        # override the default output from pydantic by calling `to_dict()` of funding_transaction
        if self.funding_transaction:
            _dict['funding_transaction'] = self.funding_transaction.to_dict()
        # override the default output from pydantic by calling `to_dict()` of response
        if self.response:
            _dict['response'] = self.response.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalFindOriginalResponse:
        """Create an instance of InternalFindOriginalResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalFindOriginalResponse.parse_obj(obj)

        _obj = InternalFindOriginalResponse.parse_obj({
            "original_found": obj.get("originalFound"),
            "original_tranlog": InternalAuthorizationTransaction.from_dict(obj.get("original_tranlog")) if obj.get("original_tranlog") is not None else None,
            "funding_transaction": FundingTranlog.from_dict(obj.get("funding_transaction")) if obj.get("funding_transaction") is not None else None,
            "finder_name": obj.get("finder_name"),
            "context": obj.get("context"),
            "response": Response.from_dict(obj.get("response")) if obj.get("response") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime

from pydantic import BaseModel, Field, StrictStr
from marqeta_client.models.xpay_push_tokenize_request_data import XpayPushTokenizeRequestData

class DigitalWalletXPayProvisionResponse(BaseModel):
    """
    DigitalWalletXPayProvisionResponse
    """
    created_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    last_modified_time: datetime = Field(..., description="yyyy-MM-ddTHH:mm:ssZ")
    card_token: StrictStr = ...
    push_tokenize_request_data: XpayPushTokenizeRequestData = ...
    __properties = ["created_time", "last_modified_time", "card_token", "push_tokenize_request_data"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DigitalWalletXPayProvisionResponse:
        """Create an instance of DigitalWalletXPayProvisionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of push_tokenize_request_data
        if self.push_tokenize_request_data:
            _dict['push_tokenize_request_data'] = self.push_tokenize_request_data.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DigitalWalletXPayProvisionResponse:
        """Create an instance of DigitalWalletXPayProvisionResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DigitalWalletXPayProvisionResponse.parse_obj(obj)

        _obj = DigitalWalletXPayProvisionResponse.parse_obj({
            "created_time": obj.get("created_time"),
            "last_modified_time": obj.get("last_modified_time"),
            "card_token": obj.get("card_token"),
            "push_tokenize_request_data": XpayPushTokenizeRequestData.from_dict(obj.get("push_tokenize_request_data")) if obj.get("push_tokenize_request_data") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr, validator
from marqeta_client.models.digital_wallet_token_hash import DigitalWalletTokenHash

class DigitalWalletTokenTransitionRequest(BaseModel):
    """
    DigitalWalletTokenTransitionRequest
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    reason_code: Optional[StrictStr] = None
    token_reference_id: Optional[StrictStr] = None
    channel: Optional[StrictStr] = None
    digital_wallet_token: DigitalWalletTokenHash = ...
    state: StrictStr = ...
    reason: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    override_tsp_error: Optional[StrictBool] = False
    __properties = ["token", "reason_code", "token_reference_id", "channel", "digital_wallet_token", "state", "reason", "override_tsp_error"]

    @validator('reason_code')
    def reason_code_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('00', '01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31'):
            raise ValueError("must be one of enum values ('00', '01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31')")
        return v

    @validator('channel')
    def channel_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('TOKEN_SERVICE_PROVIDER', 'TOKEN_SERVICE_PROVIDER_API', 'DIGITAL_WALLET', 'API', 'IVR', 'FRAUD', 'ADMIN', 'SYSTEM'):
            raise ValueError("must be one of enum values ('TOKEN_SERVICE_PROVIDER', 'TOKEN_SERVICE_PROVIDER_API', 'DIGITAL_WALLET', 'API', 'IVR', 'FRAUD', 'ADMIN', 'SYSTEM')")
        return v

    @validator('state')
    def state_validate_enum(cls, v):
        if v not in ('ACTIVE', 'SUSPENDED', 'TERMINATED'):
            raise ValueError("must be one of enum values ('ACTIVE', 'SUSPENDED', 'TERMINATED')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DigitalWalletTokenTransitionRequest:
        """Create an instance of DigitalWalletTokenTransitionRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of digital_wallet_token
        if self.digital_wallet_token:
            _dict['digital_wallet_token'] = self.digital_wallet_token.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DigitalWalletTokenTransitionRequest:
        """Create an instance of DigitalWalletTokenTransitionRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DigitalWalletTokenTransitionRequest.parse_obj(obj)

        _obj = DigitalWalletTokenTransitionRequest.parse_obj({
            "token": obj.get("token"),
            "reason_code": obj.get("reason_code"),
            "token_reference_id": obj.get("token_reference_id"),
            "channel": obj.get("channel"),
            "digital_wallet_token": DigitalWalletTokenHash.from_dict(obj.get("digital_wallet_token")) if obj.get("digital_wallet_token") is not None else None,
            "state": obj.get("state"),
            "reason": obj.get("reason"),
            "override_tsp_error": obj.get("override_tsp_error") if obj.get("override_tsp_error") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, Field, StrictBool, StrictInt, StrictStr

class CronJobInfo(BaseModel):
    """
    CronJobInfo
    """
    schedule: Optional[StrictStr] = None
    group: Optional[StrictStr] = None
    id: Optional[StrictStr] = None
    var_class: Optional[StrictStr] = Field(None, alias="class")
    is_running: Optional[StrictBool] = None
    last_run_duration_millis: Optional[StrictInt] = None
    next_run: Optional[datetime] = None
    last_run: Optional[datetime] = None
    timezone: Optional[StrictStr] = None
    start_time: Optional[datetime] = None
    __properties = ["schedule", "group", "id", "class", "is_running", "last_run_duration_millis", "next_run", "last_run", "timezone", "start_time"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CronJobInfo:
        """Create an instance of CronJobInfo from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "start_time",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CronJobInfo:
        """Create an instance of CronJobInfo from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CronJobInfo.parse_obj(obj)

        _obj = CronJobInfo.parse_obj({
            "schedule": obj.get("schedule"),
            "group": obj.get("group"),
            "id": obj.get("id"),
            "var_class": obj.get("class"),
            "is_running": obj.get("is_running"),
            "last_run_duration_millis": obj.get("last_run_duration_millis"),
            "next_run": obj.get("next_run"),
            "last_run": obj.get("last_run"),
            "timezone": obj.get("timezone"),
            "start_time": obj.get("start_time")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Dict, Optional
from pydantic import BaseModel, Field, StrictStr
from marqeta_client.models.taba_pay_card import TabaPayCard
from marqeta_client.models.taba_pay_owner import TabaPayOwner

class TabaPayAddPaymentInstrumentRequest(BaseModel):
    """
    TabaPayAddPaymentInstrumentRequest
    """
    entity: Optional[TabaPayAddPaymentInstrumentRequest] = None
    tags: Optional[Dict[str, StrictStr]] = None
    reference_id: Optional[StrictStr] = Field(None, alias="referenceID")
    card: Optional[TabaPayCard] = None
    owner: Optional[TabaPayOwner] = None
    __properties = ["entity", "tags", "referenceID", "card", "owner"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> TabaPayAddPaymentInstrumentRequest:
        """Create an instance of TabaPayAddPaymentInstrumentRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of entity
        if self.entity:
            _dict['entity'] = self.entity.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        # override the default output from pydantic by calling `to_dict()` of owner
        if self.owner:
            _dict['owner'] = self.owner.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> TabaPayAddPaymentInstrumentRequest:
        """Create an instance of TabaPayAddPaymentInstrumentRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return TabaPayAddPaymentInstrumentRequest.parse_obj(obj)

        _obj = TabaPayAddPaymentInstrumentRequest.parse_obj({
            "entity": TabaPayAddPaymentInstrumentRequest.from_dict(obj.get("entity")) if obj.get("entity") is not None else None,
            "tags": obj.get("tags"),
            "reference_id": obj.get("referenceID"),
            "card": TabaPayCard.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "owner": TabaPayOwner.from_dict(obj.get("owner")) if obj.get("owner") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr
from marqeta_client.models.internal_funding_source import InternalFundingSource
from marqeta_client.models.internal_gateway_merchant import InternalGatewayMerchant
from marqeta_client.models.internal_user import InternalUser
from marqeta_client.models.network_metadata import NetworkMetadata

class InternalGatewayLog(BaseModel):
    """
    InternalGatewayLog
    """
    gateway_merchant: Optional[InternalGatewayMerchant] = Field(None, alias="gatewayMerchant")
    order_id: Optional[StrictStr] = Field(None, alias="orderId")
    request_method: Optional[StrictStr] = Field(None, alias="requestMethod")
    gateway_request_method: Optional[StrictStr] = Field(None, alias="gatewayRequestMethod")
    response_code: Optional[StrictStr] = Field(None, alias="responseCode")
    response_sub_code: Optional[StrictStr] = Field(None, alias="responseSubCode")
    response_reason_code: Optional[StrictStr] = Field(None, alias="responseReasonCode")
    response_message: Optional[StrictStr] = Field(None, alias="responseMessage")
    gateway_response_message: Optional[StrictStr] = Field(None, alias="gatewayResponseMessage")
    response_status: Optional[StrictStr] = Field(None, alias="responseStatus")
    gateway_transaction_id: Optional[StrictStr] = Field(None, alias="gatewayTransactionId")
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    api_duration: Optional[StrictInt] = Field(None, alias="apiDuration")
    gateway_duration: Optional[StrictInt] = Field(None, alias="gatewayDuration")
    memo: Optional[StrictStr] = None
    gateway_version: Optional[StrictStr] = Field(None, alias="gatewayVersion")
    funding_source: InternalFundingSource = ...
    internal_user: Optional[InternalUser] = Field(None, alias="internalUser")
    network_metadata: Optional[NetworkMetadata] = None
    __properties = ["gatewayMerchant", "orderId", "requestMethod", "gatewayRequestMethod", "responseCode", "responseSubCode", "responseReasonCode", "responseMessage", "gatewayResponseMessage", "responseStatus", "gatewayTransactionId", "amount", "apiDuration", "gatewayDuration", "memo", "gatewayVersion", "funding_source", "internalUser", "network_metadata"]

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> InternalGatewayLog:
        """Create an instance of InternalGatewayLog from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of gateway_merchant
        if self.gateway_merchant:
            _dict['gatewayMerchant'] = self.gateway_merchant.to_dict()
        # override the default output from pydantic by calling `to_dict()` of funding_source
        if self.funding_source:
            _dict['funding_source'] = self.funding_source.to_dict()
        # override the default output from pydantic by calling `to_dict()` of internal_user
        if self.internal_user:
            _dict['internalUser'] = self.internal_user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of network_metadata
        if self.network_metadata:
            _dict['network_metadata'] = self.network_metadata.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> InternalGatewayLog:
        """Create an instance of InternalGatewayLog from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return InternalGatewayLog.parse_obj(obj)

        _obj = InternalGatewayLog.parse_obj({
            "gateway_merchant": InternalGatewayMerchant.from_dict(obj.get("gatewayMerchant")) if obj.get("gatewayMerchant") is not None else None,
            "order_id": obj.get("orderId"),
            "request_method": obj.get("requestMethod"),
            "gateway_request_method": obj.get("gatewayRequestMethod"),
            "response_code": obj.get("responseCode"),
            "response_sub_code": obj.get("responseSubCode"),
            "response_reason_code": obj.get("responseReasonCode"),
            "response_message": obj.get("responseMessage"),
            "gateway_response_message": obj.get("gatewayResponseMessage"),
            "response_status": obj.get("responseStatus"),
            "gateway_transaction_id": obj.get("gatewayTransactionId"),
            "amount": obj.get("amount"),
            "api_duration": obj.get("apiDuration"),
            "gateway_duration": obj.get("gatewayDuration"),
            "memo": obj.get("memo"),
            "gateway_version": obj.get("gatewayVersion"),
            "funding_source": InternalFundingSource.from_dict(obj.get("funding_source")) if obj.get("funding_source") is not None else None,
            "internal_user": InternalUser.from_dict(obj.get("internalUser")) if obj.get("internalUser") is not None else None,
            "network_metadata": NetworkMetadata.from_dict(obj.get("network_metadata")) if obj.get("network_metadata") is not None else None
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictStr, validator

class OriginalCredit(BaseModel):
    """
    OriginalCredit
    """
    transaction_type: Optional[StrictStr] = None
    funding_source: Optional[StrictStr] = None
    sender_account_type: Optional[StrictStr] = None
    sender_name: Optional[StrictStr] = None
    sender_address: Optional[StrictStr] = None
    sender_city: Optional[StrictStr] = None
    sender_state: Optional[StrictStr] = None
    sender_country: Optional[StrictStr] = None
    screening_score: Optional[StrictStr] = None
    transaction_purpose: Optional[StrictStr] = None
    deferred_hold_by: Optional[StrictStr] = None
    __properties = ["transaction_type", "funding_source", "sender_account_type", "sender_name", "sender_address", "sender_city", "sender_state", "sender_country", "screening_score", "transaction_purpose", "deferred_hold_by"]

    @validator('transaction_type')
    def transaction_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('account_to_account', 'person_to_person', 'wallet_transfer', 'money_transfer_by_bank', 'business_to_business', 'disbursement', 'government_disbursement', 'gambling_payout', 'loyalty', 'merchant_disbursement', 'online_gambling_payout', 'pension_disbursement', 'prepaid_loads', 'card_bill_payment', 'bill_payment', 'cash_claim', 'cash_in', 'cash_out', 'mobile_air_time_payment', 'money_transfer_by_merchant', 'face_to_face_merchant_payment', 'government_payment', 'payments_goods_services', 'funds_transfer', 'general_business_to_business_transfer', 'business_to_business_transfer', 'cash_deposit'):
            raise ValueError("must be one of enum values ('account_to_account', 'person_to_person', 'wallet_transfer', 'money_transfer_by_bank', 'business_to_business', 'disbursement', 'government_disbursement', 'gambling_payout', 'loyalty', 'merchant_disbursement', 'online_gambling_payout', 'pension_disbursement', 'prepaid_loads', 'card_bill_payment', 'bill_payment', 'cash_claim', 'cash_in', 'cash_out', 'mobile_air_time_payment', 'money_transfer_by_merchant', 'face_to_face_merchant_payment', 'government_payment', 'payments_goods_services', 'funds_transfer', 'general_business_to_business_transfer', 'business_to_business_transfer', 'cash_deposit')")
        return v

    @validator('funding_source')
    def funding_source_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('CREDIT', 'DEBIT', 'PREPAID', 'DEPOSIT_ACCOUNT', 'CASH', 'MOBILE_MONEY_ACCOUNT', 'NON_VISA_CREDIT'):
            raise ValueError("must be one of enum values ('CREDIT', 'DEBIT', 'PREPAID', 'DEPOSIT_ACCOUNT', 'CASH', 'MOBILE_MONEY_ACCOUNT', 'NON_VISA_CREDIT')")
        return v

    @validator('sender_account_type')
    def sender_account_type_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('OTHER', 'RTN_BANK_ACCOUNT', 'IBAN', 'CARD_ACCOUNT', 'EMAIL', 'PHONE_NUMBER', 'BANK_ACCOUNT_NUMBER_AND_BANK_IDENTIFICATION_CODE', 'WALLET_ID', 'SOCIAL_NETWORK_ID'):
            raise ValueError("must be one of enum values ('OTHER', 'RTN_BANK_ACCOUNT', 'IBAN', 'CARD_ACCOUNT', 'EMAIL', 'PHONE_NUMBER', 'BANK_ACCOUNT_NUMBER_AND_BANK_IDENTIFICATION_CODE', 'WALLET_ID', 'SOCIAL_NETWORK_ID')")
        return v

    @validator('deferred_hold_by')
    def deferred_hold_by_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('absent', 'visa', 'originator'):
            raise ValueError("must be one of enum values ('absent', 'visa', 'originator')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> OriginalCredit:
        """Create an instance of OriginalCredit from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> OriginalCredit:
        """Create an instance of OriginalCredit from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return OriginalCredit.parse_obj(obj)

        _obj = OriginalCredit.parse_obj({
            "transaction_type": obj.get("transaction_type"),
            "funding_source": obj.get("funding_source"),
            "sender_account_type": obj.get("sender_account_type"),
            "sender_name": obj.get("sender_name"),
            "sender_address": obj.get("sender_address"),
            "sender_city": obj.get("sender_city"),
            "sender_state": obj.get("sender_state"),
            "sender_country": obj.get("sender_country"),
            "screening_score": obj.get("screening_score"),
            "transaction_purpose": obj.get("transaction_purpose"),
            "deferred_hold_by": obj.get("deferred_hold_by")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Dict, List, Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, conlist, constr, validator
from marqeta_client.models.account_funding_request import AccountFundingRequest
from marqeta_client.models.acquirer import Acquirer
from marqeta_client.models.advanced_auth_card_acceptor_model import AdvancedAuthCardAcceptorModel
from marqeta_client.models.advanced_auth_card_options import AdvancedAuthCardOptions
from marqeta_client.models.advanced_auth_poi import AdvancedAuthPOI
from marqeta_client.models.digital_wallet_token_device import DigitalWalletTokenDevice
from marqeta_client.models.digital_wallet_token_wallet_provider import DigitalWalletTokenWalletProvider
from marqeta_client.models.iso8583_digital_wallet_token import Iso8583DigitalWalletToken
from marqeta_client.models.network_fee_model import NetworkFeeModel
from marqeta_client.models.network_metadata import NetworkMetadata
from marqeta_client.models.original_data_elements import OriginalDataElements
from marqeta_client.models.replacement_amount import ReplacementAmount
from marqeta_client.models.transaction_options import TransactionOptions
from marqeta_client.models.webhook import Webhook

class AdvAuthRequestModel(BaseModel):
    """
    AdvAuthRequestModel
    """
    extended_stip_reason_code: Optional[StrictStr] = Field(None, alias="extendedStipReasonCode")
    mti: Optional[StrictStr] = Field(None, description="Default is 0100")
    network: StrictStr = ...
    sub_network: Optional[StrictStr] = Field(None, description="Defaults to VISANET if network is VISA")
    network_reference_id: Optional[StrictStr] = None
    local_transaction_date: Optional[datetime] = Field(None, description="yyyy-MM-dd, yyyy-MM-ddThh:mm:ssZ")
    transaction_date: Optional[datetime] = Field(None, description="yyyy-MM-dd, yyyy-MM-ddThh:mm:ssZ")
    settlement_date: Optional[datetime] = Field(None, description="yyyy-MM-dd, yyyy-MM-ddThh:mm:ssZ")
    stan: Optional[StrictStr] = None
    rrn: Optional[StrictStr] = None
    processing_code: Optional[StrictStr] = None
    function_code: Optional[StrictStr] = None
    reason_code: Optional[StrictStr] = None
    rejection_code: Optional[constr(strict=True, max_length=4, min_length=0)] = None
    acquirer_reference_id: Optional[StrictStr] = None
    forwarding_institution_id: Optional[constr(strict=True, max_length=11, min_length=11)] = None
    local_transaction_amount: Optional[Union[StrictFloat, StrictInt]] = None
    local_currency_code: Optional[StrictStr] = None
    settlement_amount: Optional[Union[StrictFloat, StrictInt]] = None
    cardholder_billing_amount: Optional[Union[StrictFloat, StrictInt]] = None
    cardholder_billing_conversion_rate: Optional[Union[StrictFloat, StrictInt]] = None
    cardholder_billing_currency: Optional[StrictStr] = None
    settlement_currency_code: Optional[StrictStr] = None
    cardholder_settlement_conversion_rate: Optional[Union[StrictFloat, StrictInt]] = None
    approval_code: Optional[StrictStr] = None
    network_response: Optional[constr(strict=True, max_length=2, min_length=0)] = None
    stan_padding_length: Optional[StrictInt] = None
    acquirer: Optional[Acquirer] = None
    payment_account_reference: Optional[StrictStr] = None
    card_token: StrictStr = ...
    amount: Optional[Union[StrictFloat, StrictInt]] = None
    cash_back_amount: Optional[Union[StrictFloat, StrictInt]] = None
    mid: Optional[StrictStr] = None
    pin: Optional[StrictStr] = None
    pos_pan_entry_mode: Optional[StrictStr] = Field(None, description="Default is MAG_STRIPE")
    acquirer_fee_amount: Optional[Union[StrictFloat, StrictInt]] = None
    stip_reason_code: Optional[StrictStr] = None
    is_recurring: Optional[StrictBool] = Field(None, description="Default is false")
    is_installment: Optional[StrictBool] = Field(None, description="Default is false")
    network_fees: Optional[conlist(NetworkFeeModel)] = None
    card_acceptor: Optional[AdvancedAuthCardAcceptorModel] = None
    transaction_options: Optional[TransactionOptions] = None
    original_data_elements: Optional[OriginalDataElements] = None
    replacement_amount: Optional[ReplacementAmount] = None
    webhook: Optional[Webhook] = None
    digital_wallet_token: Optional[Iso8583DigitalWalletToken] = None
    digital_wallet_token_device_info: Optional[DigitalWalletTokenDevice] = None
    digital_wallet_token_wallet_provider_info: Optional[DigitalWalletTokenWalletProvider] = None
    raw_iso_fields: Optional[Dict[str, StrictStr]] = None
    cavv_result_code: Optional[StrictStr] = None
    acceptance_environment_authentication_outage_indicator: Optional[StrictStr] = None
    threeds_authentication_value: Optional[StrictStr] = None
    threeds_acquirer_exemption_value: Optional[StrictStr] = None
    security_level_indicator: Optional[StrictStr] = None
    secure_payment_application_v2_value: Optional[StrictStr] = None
    from_account: Optional[StrictStr] = None
    issuer_received_time: Optional[StrictStr] = None
    network_metadata: Optional[NetworkMetadata] = None
    isa_indicator: Optional[StrictStr] = None
    payment_facilitator_id: Optional[StrictStr] = None
    independent_sales_organization_id: Optional[StrictStr] = None
    sub_merchant_id: Optional[StrictStr] = None
    country_of_origin: Optional[StrictStr] = None
    foreign_retailer_indicator: Optional[StrictStr] = None
    currency_conversion_assessment: Optional[StrictStr] = None
    transfer_service_provider_name: Optional[StrictStr] = None
    payment_facilitator_name: Optional[StrictStr] = None
    network_assigned_id: Optional[StrictStr] = None
    account_funding: Optional[AccountFundingRequest] = None
    atc_value: Optional[Union[StrictFloat, StrictInt]] = None
    atc_discrepancy_value: Optional[Union[StrictFloat, StrictInt]] = None
    atc_discrepancy_indicator: Optional[StrictStr] = None
    poi: Optional[AdvancedAuthPOI] = None
    card_options: AdvancedAuthCardOptions = ...
    is_stip_approval: Optional[StrictBool] = None
    stip_advice_detail_code_override: Optional[StrictBool] = None
    __properties = ["extendedStipReasonCode", "mti", "network", "sub_network", "network_reference_id", "local_transaction_date", "transaction_date", "settlement_date", "stan", "rrn", "processing_code", "function_code", "reason_code", "rejection_code", "acquirer_reference_id", "forwarding_institution_id", "local_transaction_amount", "local_currency_code", "settlement_amount", "cardholder_billing_amount", "cardholder_billing_conversion_rate", "cardholder_billing_currency", "settlement_currency_code", "cardholder_settlement_conversion_rate", "approval_code", "network_response", "stan_padding_length", "acquirer", "payment_account_reference", "card_token", "amount", "cash_back_amount", "mid", "pin", "pos_pan_entry_mode", "acquirer_fee_amount", "stip_reason_code", "is_recurring", "is_installment", "network_fees", "card_acceptor", "transaction_options", "original_data_elements", "replacement_amount", "webhook", "digital_wallet_token", "digital_wallet_token_device_info", "digital_wallet_token_wallet_provider_info", "raw_iso_fields", "cavv_result_code", "acceptance_environment_authentication_outage_indicator", "threeds_authentication_value", "threeds_acquirer_exemption_value", "security_level_indicator", "secure_payment_application_v2_value", "from_account", "issuer_received_time", "network_metadata", "isa_indicator", "payment_facilitator_id", "independent_sales_organization_id", "sub_merchant_id", "country_of_origin", "foreign_retailer_indicator", "currency_conversion_assessment", "transfer_service_provider_name", "payment_facilitator_name", "network_assigned_id", "account_funding", "atc_value", "atc_discrepancy_value", "atc_discrepancy_indicator", "poi", "card_options", "is_stip_approval", "stip_advice_detail_code_override"]

    @validator('mti')
    def mti_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('0100', '0120', '0190', '0200', '0220', '0400', '0420', '0620', '0110', '0130', '0210', '0410', '0430', '0230'):
            raise ValueError("must be one of enum values ('0100', '0120', '0190', '0200', '0220', '0400', '0420', '0620', '0110', '0130', '0210', '0410', '0430', '0230')")
        return v

    @validator('network')
    def network_validate_enum(cls, v):
        if v not in ('MASTERCARD', 'DISCOVER', 'PULSE', 'VISA'):
            raise ValueError("must be one of enum values ('MASTERCARD', 'DISCOVER', 'PULSE', 'VISA')")
        return v

    @validator('sub_network')
    def sub_network_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('VISANET', 'VISANETDEBIT', 'VISAINTERLINK', 'VISAPLUS', 'MAESTRO'):
            raise ValueError("must be one of enum values ('VISANET', 'VISANETDEBIT', 'VISAINTERLINK', 'VISAPLUS', 'MAESTRO')")
        return v

    @validator('pos_pan_entry_mode')
    def pos_pan_entry_mode_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('MANUAL', 'MAG_STRIPE', 'MAG_STRIPE_CONTACTLESS', 'CHIP', 'CHIP_CONTACTLESS', 'BAR_CODE', 'OCR', 'MICR', 'OTHER'):
            raise ValueError("must be one of enum values ('MANUAL', 'MAG_STRIPE', 'MAG_STRIPE_CONTACTLESS', 'CHIP', 'CHIP_CONTACTLESS', 'BAR_CODE', 'OCR', 'MICR', 'OTHER')")
        return v

    @validator('cavv_result_code')
    def cavv_result_code_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D'):
            raise ValueError("must be one of enum values ('0', '1', '2', '3', '4', '5', '6', '7', '8', '9', 'A', 'B', 'C', 'D')")
        return v

    @validator('isa_indicator')
    def isa_indicator_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('S', 'C', 'R', 'M', 'P', 'BLANK_SPACE'):
            raise ValueError("must be one of enum values ('S', 'C', 'R', 'M', 'P', 'BLANK_SPACE')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AdvAuthRequestModel:
        """Create an instance of AdvAuthRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of acquirer
        if self.acquirer:
            _dict['acquirer'] = self.acquirer.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in network_fees (list)
        _items = []
        if self.network_fees:
            for _item in self.network_fees:
                if _item:
                    _items.append(_item.to_dict())
            _dict['network_fees'] = _items
        # override the default output from pydantic by calling `to_dict()` of card_acceptor
        if self.card_acceptor:
            _dict['card_acceptor'] = self.card_acceptor.to_dict()
        # override the default output from pydantic by calling `to_dict()` of transaction_options
        if self.transaction_options:
            _dict['transaction_options'] = self.transaction_options.to_dict()
        # override the default output from pydantic by calling `to_dict()` of original_data_elements
        if self.original_data_elements:
            _dict['original_data_elements'] = self.original_data_elements.to_dict()
        # override the default output from pydantic by calling `to_dict()` of replacement_amount
        if self.replacement_amount:
            _dict['replacement_amount'] = self.replacement_amount.to_dict()
        # override the default output from pydantic by calling `to_dict()` of webhook
        if self.webhook:
            _dict['webhook'] = self.webhook.to_dict()
        # override the default output from pydantic by calling `to_dict()` of digital_wallet_token
        if self.digital_wallet_token:
            _dict['digital_wallet_token'] = self.digital_wallet_token.to_dict()
        # override the default output from pydantic by calling `to_dict()` of digital_wallet_token_device_info
        if self.digital_wallet_token_device_info:
            _dict['digital_wallet_token_device_info'] = self.digital_wallet_token_device_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of digital_wallet_token_wallet_provider_info
        if self.digital_wallet_token_wallet_provider_info:
            _dict['digital_wallet_token_wallet_provider_info'] = self.digital_wallet_token_wallet_provider_info.to_dict()
        # override the default output from pydantic by calling `to_dict()` of network_metadata
        if self.network_metadata:
            _dict['network_metadata'] = self.network_metadata.to_dict()
        # override the default output from pydantic by calling `to_dict()` of account_funding
        if self.account_funding:
            _dict['account_funding'] = self.account_funding.to_dict()
        # override the default output from pydantic by calling `to_dict()` of poi
        if self.poi:
            _dict['poi'] = self.poi.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card_options
        if self.card_options:
            _dict['card_options'] = self.card_options.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AdvAuthRequestModel:
        """Create an instance of AdvAuthRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AdvAuthRequestModel.parse_obj(obj)

        _obj = AdvAuthRequestModel.parse_obj({
            "extended_stip_reason_code": obj.get("extendedStipReasonCode"),
            "mti": obj.get("mti"),
            "network": obj.get("network"),
            "sub_network": obj.get("sub_network"),
            "network_reference_id": obj.get("network_reference_id"),
            "local_transaction_date": obj.get("local_transaction_date"),
            "transaction_date": obj.get("transaction_date"),
            "settlement_date": obj.get("settlement_date"),
            "stan": obj.get("stan"),
            "rrn": obj.get("rrn"),
            "processing_code": obj.get("processing_code"),
            "function_code": obj.get("function_code"),
            "reason_code": obj.get("reason_code"),
            "rejection_code": obj.get("rejection_code"),
            "acquirer_reference_id": obj.get("acquirer_reference_id"),
            "forwarding_institution_id": obj.get("forwarding_institution_id"),
            "local_transaction_amount": obj.get("local_transaction_amount"),
            "local_currency_code": obj.get("local_currency_code"),
            "settlement_amount": obj.get("settlement_amount"),
            "cardholder_billing_amount": obj.get("cardholder_billing_amount"),
            "cardholder_billing_conversion_rate": obj.get("cardholder_billing_conversion_rate"),
            "cardholder_billing_currency": obj.get("cardholder_billing_currency"),
            "settlement_currency_code": obj.get("settlement_currency_code"),
            "cardholder_settlement_conversion_rate": obj.get("cardholder_settlement_conversion_rate"),
            "approval_code": obj.get("approval_code"),
            "network_response": obj.get("network_response"),
            "stan_padding_length": obj.get("stan_padding_length"),
            "acquirer": Acquirer.from_dict(obj.get("acquirer")) if obj.get("acquirer") is not None else None,
            "payment_account_reference": obj.get("payment_account_reference"),
            "card_token": obj.get("card_token"),
            "amount": obj.get("amount"),
            "cash_back_amount": obj.get("cash_back_amount"),
            "mid": obj.get("mid"),
            "pin": obj.get("pin"),
            "pos_pan_entry_mode": obj.get("pos_pan_entry_mode"),
            "acquirer_fee_amount": obj.get("acquirer_fee_amount"),
            "stip_reason_code": obj.get("stip_reason_code"),
            "is_recurring": obj.get("is_recurring"),
            "is_installment": obj.get("is_installment"),
            "network_fees": [NetworkFeeModel.from_dict(_item) for _item in obj.get("network_fees")] if obj.get("network_fees") is not None else None,
            "card_acceptor": AdvancedAuthCardAcceptorModel.from_dict(obj.get("card_acceptor")) if obj.get("card_acceptor") is not None else None,
            "transaction_options": TransactionOptions.from_dict(obj.get("transaction_options")) if obj.get("transaction_options") is not None else None,
            "original_data_elements": OriginalDataElements.from_dict(obj.get("original_data_elements")) if obj.get("original_data_elements") is not None else None,
            "replacement_amount": ReplacementAmount.from_dict(obj.get("replacement_amount")) if obj.get("replacement_amount") is not None else None,
            "webhook": Webhook.from_dict(obj.get("webhook")) if obj.get("webhook") is not None else None,
            "digital_wallet_token": Iso8583DigitalWalletToken.from_dict(obj.get("digital_wallet_token")) if obj.get("digital_wallet_token") is not None else None,
            "digital_wallet_token_device_info": DigitalWalletTokenDevice.from_dict(obj.get("digital_wallet_token_device_info")) if obj.get("digital_wallet_token_device_info") is not None else None,
            "digital_wallet_token_wallet_provider_info": DigitalWalletTokenWalletProvider.from_dict(obj.get("digital_wallet_token_wallet_provider_info")) if obj.get("digital_wallet_token_wallet_provider_info") is not None else None,
            "raw_iso_fields": obj.get("raw_iso_fields"),
            "cavv_result_code": obj.get("cavv_result_code"),
            "acceptance_environment_authentication_outage_indicator": obj.get("acceptance_environment_authentication_outage_indicator"),
            "threeds_authentication_value": obj.get("threeds_authentication_value"),
            "threeds_acquirer_exemption_value": obj.get("threeds_acquirer_exemption_value"),
            "security_level_indicator": obj.get("security_level_indicator"),
            "secure_payment_application_v2_value": obj.get("secure_payment_application_v2_value"),
            "from_account": obj.get("from_account"),
            "issuer_received_time": obj.get("issuer_received_time"),
            "network_metadata": NetworkMetadata.from_dict(obj.get("network_metadata")) if obj.get("network_metadata") is not None else None,
            "isa_indicator": obj.get("isa_indicator"),
            "payment_facilitator_id": obj.get("payment_facilitator_id"),
            "independent_sales_organization_id": obj.get("independent_sales_organization_id"),
            "sub_merchant_id": obj.get("sub_merchant_id"),
            "country_of_origin": obj.get("country_of_origin"),
            "foreign_retailer_indicator": obj.get("foreign_retailer_indicator"),
            "currency_conversion_assessment": obj.get("currency_conversion_assessment"),
            "transfer_service_provider_name": obj.get("transfer_service_provider_name"),
            "payment_facilitator_name": obj.get("payment_facilitator_name"),
            "network_assigned_id": obj.get("network_assigned_id"),
            "account_funding": AccountFundingRequest.from_dict(obj.get("account_funding")) if obj.get("account_funding") is not None else None,
            "atc_value": obj.get("atc_value"),
            "atc_discrepancy_value": obj.get("atc_discrepancy_value"),
            "atc_discrepancy_indicator": obj.get("atc_discrepancy_indicator"),
            "poi": AdvancedAuthPOI.from_dict(obj.get("poi")) if obj.get("poi") is not None else None,
            "card_options": AdvancedAuthCardOptions.from_dict(obj.get("card_options")) if obj.get("card_options") is not None else None,
            "is_stip_approval": obj.get("is_stip_approval"),
            "stip_advice_detail_code_override": obj.get("stip_advice_detail_code_override")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr, validator

class BaseAchRequestModel(BaseModel):
    """
    BaseAchRequestModel
    """
    token: Optional[constr(strict=True, max_length=36, min_length=1)] = None
    account_number: StrictStr = ...
    routing_number: StrictStr = ...
    name_on_account: constr(strict=True, max_length=50, min_length=1) = ...
    account_type: StrictStr = ...
    bank_name: Optional[StrictStr] = None
    verification_override: Optional[StrictBool] = False
    verification_notes: Optional[StrictStr] = None
    is_default_account: Optional[StrictBool] = False
    __properties = ["token", "account_number", "routing_number", "name_on_account", "account_type", "bank_name", "verification_override", "verification_notes", "is_default_account"]

    @validator('account_type')
    def account_type_validate_enum(cls, v):
        if v not in ('checking', 'savings', 'corporate', 'loan'):
            raise ValueError("must be one of enum values ('checking', 'savings', 'corporate', 'loan')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> BaseAchRequestModel:
        """Create an instance of BaseAchRequestModel from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "routing_number",
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> BaseAchRequestModel:
        """Create an instance of BaseAchRequestModel from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return BaseAchRequestModel.parse_obj(obj)

        _obj = BaseAchRequestModel.parse_obj({
            "token": obj.get("token"),
            "account_number": obj.get("account_number"),
            "routing_number": obj.get("routing_number"),
            "name_on_account": obj.get("name_on_account"),
            "account_type": obj.get("account_type"),
            "bank_name": obj.get("bank_name"),
            "verification_override": obj.get("verification_override") if obj.get("verification_override") is not None else False,
            "verification_notes": obj.get("verification_notes"),
            "is_default_account": obj.get("is_default_account") if obj.get("is_default_account") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional, Union
from pydantic import BaseModel, Field, StrictBool, StrictFloat, StrictInt, StrictStr, constr, validator

class DirectDepositRequest(BaseModel):
    """
    DirectDepositRequest
    """
    token: Optional[constr(strict=True, max_length=36, min_length=0)] = None
    amount: Union[StrictFloat, StrictInt] = ...
    type: StrictStr = ...
    account_number: StrictStr = ...
    settlement_date: datetime = ...
    standard_entry_class_code: Optional[constr(strict=True, max_length=3, min_length=0)] = None
    company_name: Optional[constr(strict=True, max_length=16, min_length=0)] = None
    company_discretionary_data: Optional[constr(strict=True, max_length=20, min_length=0)] = None
    company_identification: Optional[constr(strict=True, max_length=10, min_length=0)] = None
    company_entry_description: Optional[constr(strict=True, max_length=10, min_length=0)] = None
    individual_identification_number: Optional[constr(strict=True, max_length=22, min_length=0)] = None
    individual_name: Optional[constr(strict=True, max_length=35, min_length=0)] = None
    early_pay_eligible: Optional[StrictBool] = Field(False, alias="earlyPayEligible")
    __properties = ["token", "amount", "type", "account_number", "settlement_date", "standard_entry_class_code", "company_name", "company_discretionary_data", "company_identification", "company_entry_description", "individual_identification_number", "individual_name", "earlyPayEligible"]

    @validator('type')
    def type_validate_enum(cls, v):
        if v not in ('CREDIT', 'DEBIT'):
            raise ValueError("must be one of enum values ('CREDIT', 'DEBIT')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> DirectDepositRequest:
        """Create an instance of DirectDepositRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> DirectDepositRequest:
        """Create an instance of DirectDepositRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return DirectDepositRequest.parse_obj(obj)

        _obj = DirectDepositRequest.parse_obj({
            "token": obj.get("token"),
            "amount": obj.get("amount"),
            "type": obj.get("type"),
            "account_number": obj.get("account_number"),
            "settlement_date": obj.get("settlement_date"),
            "standard_entry_class_code": obj.get("standard_entry_class_code"),
            "company_name": obj.get("company_name"),
            "company_discretionary_data": obj.get("company_discretionary_data"),
            "company_identification": obj.get("company_identification"),
            "company_entry_description": obj.get("company_entry_description"),
            "individual_identification_number": obj.get("individual_identification_number"),
            "individual_name": obj.get("individual_name"),
            "early_pay_eligible": obj.get("earlyPayEligible") if obj.get("earlyPayEligible") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, validator
from marqeta_client.models.advanced_auth_other_poi import AdvancedAuthOtherPOI

class AdvancedAuthPOI(BaseModel):
    """
    AdvancedAuthPOI
    """
    other: Optional[AdvancedAuthOtherPOI] = None
    ecommerce: Optional[StrictBool] = None
    atm: Optional[StrictBool] = None
    moto: Optional[StrictBool] = None
    moto_indicator: Optional[StrictStr] = None
    __properties = ["other", "ecommerce", "atm", "moto", "moto_indicator"]

    @validator('moto_indicator')
    def moto_indicator_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('UNKNOWN', 'MANUAL', 'RECURRING', 'INSTALLMENT', 'OTHERS', 'EMPTY', 'AUTH_SUCCESS', 'NON_AUTH_3D_SECURE', 'NON_AUTH_SECURE_SUBMISSION'):
            raise ValueError("must be one of enum values ('UNKNOWN', 'MANUAL', 'RECURRING', 'INSTALLMENT', 'OTHERS', 'EMPTY', 'AUTH_SUCCESS', 'NON_AUTH_3D_SECURE', 'NON_AUTH_SECURE_SUBMISSION')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> AdvancedAuthPOI:
        """Create an instance of AdvancedAuthPOI from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of other
        if self.other:
            _dict['other'] = self.other.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> AdvancedAuthPOI:
        """Create an instance of AdvancedAuthPOI from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return AdvancedAuthPOI.parse_obj(obj)

        _obj = AdvancedAuthPOI.parse_obj({
            "other": AdvancedAuthOtherPOI.from_dict(obj.get("other")) if obj.get("other") is not None else None,
            "ecommerce": obj.get("ecommerce"),
            "atm": obj.get("atm"),
            "moto": obj.get("moto"),
            "moto_indicator": obj.get("moto_indicator")
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json

from datetime import datetime
from typing import Optional
from pydantic import BaseModel, StrictBool, StrictStr, constr, validator
from marqeta_client.models.card_fulfillment_request import CardFulfillmentRequest
from marqeta_client.models.card_metadata import CardMetadata
from marqeta_client.models.cardholder_metadata import CardholderMetadata
from marqeta_client.models.validations_response import ValidationsResponse

class CardTransitionResponse(BaseModel):
    """
    CardTransitionResponse
    """
    token: constr(strict=True, max_length=36, min_length=1) = ...
    card_token: constr(strict=True, max_length=36, min_length=1) = ...
    user_token: constr(strict=True, max_length=36, min_length=1) = ...
    state: StrictStr = ...
    reason: Optional[constr(strict=True, max_length=255, min_length=0)] = None
    reason_code: Optional[StrictStr] = None
    channel: StrictStr = ...
    fulfillment_status: StrictStr = ...
    validations: Optional[ValidationsResponse] = None
    type: StrictStr = ...
    created_time: Optional[datetime] = None
    card_product_token: constr(strict=True, max_length=36, min_length=0) = ...
    last_four: StrictStr = ...
    pan: StrictStr = ...
    expiration: StrictStr = ...
    expiration_time: StrictStr = ...
    barcode: StrictStr = ...
    pin_is_set: StrictBool = ...
    fulfillment: Optional[CardFulfillmentRequest] = None
    bulk_issuance_token: Optional[StrictStr] = None
    reissue_pan_from_card_token: Optional[StrictStr] = None
    new_pan_from_card_token: Optional[StrictStr] = None
    user: Optional[CardholderMetadata] = None
    card: Optional[CardMetadata] = None
    expedite: Optional[StrictBool] = False
    __properties = ["token", "card_token", "user_token", "state", "reason", "reason_code", "channel", "fulfillment_status", "validations", "type", "created_time", "card_product_token", "last_four", "pan", "expiration", "expiration_time", "barcode", "pin_is_set", "fulfillment", "bulk_issuance_token", "reissue_pan_from_card_token", "new_pan_from_card_token", "user", "card", "expedite"]

    @validator('state')
    def state_validate_enum(cls, v):
        if v not in ('ACTIVE', 'SUSPENDED', 'TERMINATED', 'UNACTIVATED'):
            raise ValueError("must be one of enum values ('ACTIVE', 'SUSPENDED', 'TERMINATED', 'UNACTIVATED')")
        return v

    @validator('reason_code')
    def reason_code_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('00', '01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31'):
            raise ValueError("must be one of enum values ('00', '01', '02', '03', '04', '05', '06', '07', '08', '09', '10', '11', '12', '13', '14', '15', '16', '17', '18', '19', '20', '21', '22', '23', '24', '25', '26', '27', '28', '29', '30', '31')")
        return v

    @validator('channel')
    def channel_validate_enum(cls, v):
        if v not in ('API', 'IVR', 'FRAUD', 'ADMIN', 'SYSTEM'):
            raise ValueError("must be one of enum values ('API', 'IVR', 'FRAUD', 'ADMIN', 'SYSTEM')")
        return v

    @validator('fulfillment_status')
    def fulfillment_status_validate_enum(cls, v):
        if v not in ('ISSUED', 'ORDERED', 'REJECTED', 'SHIPPED', 'DELIVERED', 'DIGITALLY_PRESENTED'):
            raise ValueError("must be one of enum values ('ISSUED', 'ORDERED', 'REJECTED', 'SHIPPED', 'DELIVERED', 'DIGITALLY_PRESENTED')")
        return v

    @validator('type')
    def type_validate_enum(cls, v):
        if v not in ('fulfillment.issued', 'state.activated', 'state.suspended', 'state.reinstated', 'state.terminated', 'state.limited', 'fulfillment.ordered', 'fulfillment.rejected', 'fulfillment.shipped', 'fulfillment.delivered', 'fulfillment.digitally_presented'):
            raise ValueError("must be one of enum values ('fulfillment.issued', 'state.activated', 'state.suspended', 'state.reinstated', 'state.terminated', 'state.limited', 'fulfillment.ordered', 'fulfillment.rejected', 'fulfillment.shipped', 'fulfillment.delivered', 'fulfillment.digitally_presented')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> CardTransitionResponse:
        """Create an instance of CardTransitionResponse from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                            "type",
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of validations
        if self.validations:
            _dict['validations'] = self.validations.to_dict()
        # override the default output from pydantic by calling `to_dict()` of fulfillment
        if self.fulfillment:
            _dict['fulfillment'] = self.fulfillment.to_dict()
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of card
        if self.card:
            _dict['card'] = self.card.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> CardTransitionResponse:
        """Create an instance of CardTransitionResponse from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return CardTransitionResponse.parse_obj(obj)

        _obj = CardTransitionResponse.parse_obj({
            "token": obj.get("token"),
            "card_token": obj.get("card_token"),
            "user_token": obj.get("user_token"),
            "state": obj.get("state"),
            "reason": obj.get("reason"),
            "reason_code": obj.get("reason_code"),
            "channel": obj.get("channel"),
            "fulfillment_status": obj.get("fulfillment_status"),
            "validations": ValidationsResponse.from_dict(obj.get("validations")) if obj.get("validations") is not None else None,
            "type": obj.get("type"),
            "created_time": obj.get("created_time"),
            "card_product_token": obj.get("card_product_token"),
            "last_four": obj.get("last_four"),
            "pan": obj.get("pan"),
            "expiration": obj.get("expiration"),
            "expiration_time": obj.get("expiration_time"),
            "barcode": obj.get("barcode"),
            "pin_is_set": obj.get("pin_is_set") if obj.get("pin_is_set") is not None else False,
            "fulfillment": CardFulfillmentRequest.from_dict(obj.get("fulfillment")) if obj.get("fulfillment") is not None else None,
            "bulk_issuance_token": obj.get("bulk_issuance_token"),
            "reissue_pan_from_card_token": obj.get("reissue_pan_from_card_token"),
            "new_pan_from_card_token": obj.get("new_pan_from_card_token"),
            "user": CardholderMetadata.from_dict(obj.get("user")) if obj.get("user") is not None else None,
            "card": CardMetadata.from_dict(obj.get("card")) if obj.get("card") is not None else None,
            "expedite": obj.get("expedite") if obj.get("expedite") is not None else False
        })
        return _obj




# coding: utf-8

"""
    Marqeta Core API

    Simplified management of your payment programs  # noqa: E501

    The version of the OpenAPI document: 3.0.0
    Contact: dev@swadesh.co
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""


from __future__ import annotations
from inspect import getfullargspec
import pprint
import re  # noqa: F401
import json


from typing import List, Optional, Union
from pydantic import BaseModel, Field, StrictFloat, StrictInt, StrictStr, conlist, validator
from marqeta_client.models.network_fee_model import NetworkFeeModel
from marqeta_client.models.webhook import Webhook

class SimulateIncrementalAuthRequest(BaseModel):
    """
    SimulateIncrementalAuthRequest
    """
    card_token: StrictStr = Field(..., description="The card token of the original transaction")
    amount: Union[StrictFloat, StrictInt] = Field(..., description="The amount of the transaction in the clearing currency")
    settlement_currency: Optional[StrictStr] = Field(None, description="The ISO-3166-1 Alpha-3 or Numeric code for the clearing currency for the transaction")
    local_amount: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="The amount of the transaction in the local currency")
    local_currency: Optional[StrictStr] = Field(None, description="The ISO-3166-1 Alpha-3 or Numeric code for the local currency")
    currency_conversion_rate: Optional[Union[StrictFloat, StrictInt]] = Field(None, description="The conversion rate between the local and settlement currencies")
    network: StrictStr = Field(..., description="The transaction network for the authorization")
    sub_network: Optional[StrictStr] = Field(None, description="The transaction sub-network for the authorization")
    merchant_id: StrictStr = Field(..., description="The merchant id for the transaction")
    webhook: Optional[Webhook] = None
    network_fees: Optional[conlist(NetworkFeeModel)] = Field(None, description="The network fees for the transaction")
    network_reference_id: StrictStr = Field(..., description="The network reference id from the original transaction")
    __properties = ["card_token", "amount", "settlement_currency", "local_amount", "local_currency", "currency_conversion_rate", "network", "sub_network", "merchant_id", "webhook", "network_fees", "network_reference_id"]

    @validator('network')
    def network_validate_enum(cls, v):
        if v not in ('MARQETA', 'DISCOVER', 'MASTERCARD', 'PULSE', 'VISA'):
            raise ValueError("must be one of enum values ('MARQETA', 'DISCOVER', 'MASTERCARD', 'PULSE', 'VISA')")
        return v

    @validator('sub_network')
    def sub_network_validate_enum(cls, v):
        if v is None:
            return v

        if v not in ('VISANET', 'VISANETDEBIT', 'VISAINTERLINK', 'VISAPLUS', 'MAESTRO', 'CIRRUS', 'MASTERCARDDEBIT', 'GATEWAY_JIT', 'MANAGED_JIT'):
            raise ValueError("must be one of enum values ('VISANET', 'VISANETDEBIT', 'VISAINTERLINK', 'VISAPLUS', 'MAESTRO', 'CIRRUS', 'MASTERCARDDEBIT', 'GATEWAY_JIT', 'MANAGED_JIT')")
        return v

    class Config:
        allow_population_by_field_name = True
        validate_assignment = True

    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.dict(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> SimulateIncrementalAuthRequest:
        """Create an instance of SimulateIncrementalAuthRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self):
        """Returns the dictionary representation of the model using alias"""
        _dict = self.dict(by_alias=True,
                          exclude={
                          },
                          exclude_none=True)
        # override the default output from pydantic by calling `to_dict()` of webhook
        if self.webhook:
            _dict['webhook'] = self.webhook.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in network_fees (list)
        _items = []
        if self.network_fees:
            for _item in self.network_fees:
                if _item:
                    _items.append(_item.to_dict())
            _dict['network_fees'] = _items
        return _dict

    @classmethod
    def from_dict(cls, obj: dict) -> SimulateIncrementalAuthRequest:
        """Create an instance of SimulateIncrementalAuthRequest from a dict"""
        if obj is None:
            return None

        if type(obj) is not dict:
            return SimulateIncrementalAuthRequest.parse_obj(obj)

        _obj = SimulateIncrementalAuthRequest.parse_obj({
            "card_token": obj.get("card_token"),
            "amount": obj.get("amount"),
            "settlement_currency": obj.get("settlement_currency"),
            "local_amount": obj.get("local_amount"),
            "local_currency": obj.get("local_currency"),
            "currency_conversion_rate": obj.get("currency_conversion_rate"),
            "network": obj.get("network"),
            "sub_network": obj.get("sub_network"),
            "merchant_id": obj.get("merchant_id"),
            "webhook": Webhook.from_dict(obj.get("webhook")) if obj.get("webhook") is not None else None,
            "network_fees": [NetworkFeeModel.from_dict(_item) for _item in obj.get("network_fees")] if obj.get("network_fees") is not None else None,
            "network_reference_id": obj.get("network_reference_id")
        })
        return _obj

